@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 func_complete_build()
 {
@@ -76,10 +76,17 @@ usage:
         -d Compile a debug enabled version.
         -s Do NOT strip binaries even if in reselase mode.
         -l set a different library path under prefix (default is lib)
+        -P <flavor> Unix platform flavor:
+           - SOLARIS - Solaris OS
+           - OSX - Mac OSX
+           - LINUX - GNU/Linux (default)
+           - BSD - *bsd
 
    Environment variables
       CFLAGS - extra C flags to pass to the compiler
       CXXFLAGS - extra C++ flags to pass to the compiler
+      LD_FLAGS - extra LD flags to pass to the linker
+      EXTRA_CMAKE - Extra cmake flags to be passed to the build process
 EOT
 }
 
@@ -107,7 +114,7 @@ until [ -z "$1" ]; do
       "-j") shift; PROCESSORS=$1;;
       "-d") DEBUG="yes";;
       "-s") STRIP="no";;
-      *) func_usage ; exit 0 ;;
+      *) func_usage ; exit 1 ;;
    esac
    shift
 done
@@ -188,10 +195,12 @@ cd $FALCON_BUILD_TREE
 
 cmake -DCMAKE_CXX_FLAGS:STRING="$CXXFLAGS" \
       -DCMAKE_C_FLAGS:STRING="$CFLAGS" \
+      -DCMAKE_LD_FLAGS:STRING="$LDFLAGS" \
       -DCMAKE_BUILD_TYPE:STRING="$FALCON_BUILD_TYPE" \
       -DFALCON_INSTALL_TREE_LIB:STRING="$TARGET_LIB_DIR" \
       -DFALCON_INSTALL_TREE:STRING="$TARGET_DEST" \
       -DFALCON_FINAL_DESTINATION:STRING="$FINAL_DEST" \
+      $EXTRA_CMAKE \
       $FALCON_SRC_TREE \
       || func_errors
 
