@@ -42,6 +42,7 @@
 #include <falcon/stdstreams.h>
 #include <falcon/deferrorhandler.h>
 #include <falcon/transcoding.h>
+#include <falcon/path.h>
 
 #include "scriptdata.h"
 #include "fteh.h"
@@ -131,7 +132,7 @@ static void account_free( void *mem )
 	if ( mem == 0 )
 		return;
 
-	long *block = (long *) mem;
+	unsigned long *block = (unsigned long *) mem;
 	block = block - 4;
 
 	if ( block[1] != 0xFEDCBA98 ) {
@@ -149,23 +150,23 @@ static void account_free( void *mem )
 
 static void *account_realloc( void *mem, size_t size )
 {
-	long *block = (long *) mem;
+	unsigned long *block = (unsigned long *) mem;
 
 	if ( mem != 0 )
 	{
 		block = block - 4;
 		if ( block[1] != 0xFEDCBA98 ) {
 			s_validAlloc = 0;
-			block = (long *) malloc( size + 16 );
+			block = (unsigned long *) malloc( size + 16 );
 		}
 		else {
 			s_allocatedMem -= block[0];
          s_totalMem -= block[0];
-			block = (long *) realloc( block, size + 16 );
+			block = (unsigned long *) realloc( block, size + 16 );
 		}
 	}
 	else {
-		block = (long *) malloc( size + 16 );
+		block = (unsigned long *) malloc( size + 16 );
       s_outBlocks++;
       s_totalOutBlocks++;
 	}
@@ -180,7 +181,7 @@ static void *account_realloc( void *mem, size_t size )
       s_totalOutBlocks--;
    }
 
-	block[0] = (long) size;
+	block[0] = (unsigned long) size;
 	block[1] = 0xFEDCBA98;
 	return block + 4;
 }
@@ -603,10 +604,9 @@ void filterScripts()
    Script testing
 *************************************************/
 bool testScript( ScriptData *script,
-         FlcLoader *modloader, Module *core, Module *rtl, Module *testSuite,
+         FlcLoader *modloader, Module *core, Module *testSuite,
          String &reason, String &trace )
 {
-   reason = "";
    Module *scriptModule;
 
    //---------------------------------
@@ -625,9 +625,11 @@ bool testScript( ScriptData *script,
 
    Stream *source = TranscoderFactory( "utf-8", source_f, true );
 
+
    FTErrorHandler fteh;
    scriptModule = new Module();
-   scriptModule->name( script->filename() );
+   Path scriptPath( script->filename() );
+   scriptModule->name( scriptPath.getFile() );
    scriptModule->path( path );
 
    Compiler compiler( scriptModule, source );
@@ -648,13 +650,10 @@ bool testScript( ScriptData *script,
    if ( opt_timings )
       compTime = Sys::_seconds() - compTime;
 
-
    // we can get rid of the source here.
    delete source;
 
    // now compile the code.
-   // we need a place where to store the bytecode generated by the compiler.
-   Stream *bytecode_stream;
 
    // compile via assembly?
    if ( opt_compasm )
@@ -685,33 +684,17 @@ bool testScript( ScriptData *script,
       if ( opt_timings )
          genTime = Sys::_seconds() - genTime;
 
-      if( opt_compmem )
-      {
-         bytecode_stream = new StringStream;
-      }
-      else {
-         // create a temporary file
-         FileStream *fsbin = new FileStream;
-         fsbin->create( "temp_bytecode", FileStream::e_aUserWrite | FileStream::e_aReadOnly );
-         bytecode_stream = fsbin;
-         if ( ! bytecode_stream->good() )
-         {
-            reason = "Failed to open temporary binary stream temp_bytecode";
-            delete asm_stream;
-            delete bytecode_stream;
-            return false;
-         }
-      }
 
+      String scriptName = scriptModule->name();
       scriptModule->decref();
       scriptModule = new Module();
-      scriptModule->name( script->filename() );
+      scriptModule->name( scriptName );
       scriptModule->path( path );
 
       // reset input.
       asm_stream->seekBegin( 0 );
 
-      AsmCompiler compiler( scriptModule, asm_stream, bytecode_stream );
+      AsmCompiler compiler( scriptModule, asm_stream );
 
       compiler.errorHandler( &fteh );
 
@@ -727,43 +710,16 @@ bool testScript( ScriptData *script,
       delete asm_stream;
    }
    else {
-      // compile in memory?
-      if( opt_compmem ) {
-         bytecode_stream = new StringStream;
-      }
-      else {
-         // create a temporary file
-         FileStream *fsbin = new FileStream;
-         fsbin->create( "temp_bytecode", FileStream::e_aUserWrite | FileStream::e_aReadOnly );
-         bytecode_stream = fsbin;
-         if ( ! bytecode_stream->good() )
-         {
-            reason = "Failed to open temporary bytecode stream temp_bytecode";
-            delete bytecode_stream;
-            return false;
-         }
-      }
 
-      GenCode gc( bytecode_stream );
+      GenCode gc( compiler.module() );
       if ( opt_timings )
          genTime = Sys::_seconds();
       gc.generate( compiler.sourceTree() );
-      compiler.module()->setLineInfo( gc.extractLineInfo() );
+
       if ( opt_timings )
          genTime = Sys::_seconds() - genTime;
    }
 
-   // and load the bytecode
-   int64 len = bytecode_stream->seekEnd( 0 );
-   Falcon::byte *code = (Falcon::byte *) memAlloc( (uint32) len );
-   scriptModule->code( code );
-   scriptModule->codeSize( (uint32) len );
-   bytecode_stream->seekBegin( 0 );
-   bytecode_stream->read( (char *) code, (int)len );
-
-   // we can get rid of the bytecode stream
-   delete bytecode_stream;
-
    // serialization/deserialization test
    if( opt_serialize )
    {
@@ -774,9 +730,10 @@ bool testScript( ScriptData *script,
 
       scriptModule->save( module_stream, false );
       module_stream->seekBegin( 0 );
+      String scriptName = scriptModule->name();
       scriptModule->decref();
       scriptModule = new Module();
-      scriptModule->name( script->filename() );
+      scriptModule->name( scriptName );
       scriptModule->path( path );
 
       if ( ! scriptModule->load( module_stream, false ) )
@@ -794,19 +751,11 @@ bool testScript( ScriptData *script,
    // 2. link
    VMachine vmachine;
 
-   // we want to keep our own copies of the modules.
-   testSuite->incref();
-   core->incref();
-   rtl->incref();
-
-
    // so we can link them
    vmachine.link( core );
-   vmachine.link( rtl );
    vmachine.link( testSuite );
    vmachine.errorHandler( &fteh );
 
-   scriptModule->addMain();
    // use a runtime to load the module, so that it can load some modules too
    modloader->errorHandler( &fteh );
 
@@ -821,8 +770,18 @@ bool testScript( ScriptData *script,
    // we can abandon our reference to the script module
    scriptModule->decref();
 
+   //---------------------------------
+   // 3. execute
+   TestSuite::setSuccess( true );
+   TestSuite::setTimeFactor( opt_tf );
    if ( opt_timings )
-      linkTime = Sys::_seconds();
+         execTime = Sys::_seconds();
+
+   // inject args and script name
+   Item *sname = vmachine.findGlobalItem( "scriptName" );
+   *sname = new GarbageString( &vmachine, scriptModule->name() );
+   sname = vmachine.findGlobalItem( "scriptPath" );
+   *sname = new GarbageString( &vmachine, scriptModule->path() );
 
    if ( ! vmachine.link( &runtime ) )
    {
@@ -831,28 +790,19 @@ bool testScript( ScriptData *script,
       return false;
    }
 
-
    if ( opt_timings )
-         linkTime = Sys::_seconds() - linkTime;
-   //---------------------------------
-   // 3. execute
-   TestSuite::setSuccess( true );
-   TestSuite::setTimeFactor( opt_tf );
-   if ( opt_timings )
-         execTime = Sys::_seconds();
+      linkTime = Sys::_seconds();
 
-
-   // inject args and script name
-   Item *sname = vmachine.findGlobalItem( "scriptName" );
-   *sname = new GarbageString( &vmachine, scriptModule->name() );
-   sname = vmachine.findGlobalItem( "scriptPath" );
-   *sname = new GarbageString( &vmachine, scriptModule->path() );
-
-
-   vmachine.launch();
+   if ( ! vmachine.launch() )
+   {
+      trace = "";
+      reason = "Non executable script.";
+      return false;
+   }
 
    if ( opt_timings )
          execTime = Sys::_seconds() - execTime;
+
    if ( vmachine.lastEvent() != VMachine::eventQuit && vmachine.lastEvent() != VMachine::eventNone )
    {
       trace = fteh.getError();
@@ -901,14 +851,14 @@ void gauge()
    }
 }
 
-void executeTests( FlcLoader *modloader, Module *rtl )
+void executeTests( FlcLoader *modloader )
 {
    Module *core = Falcon::core_module_init();
    Module *testSuite = init_testsuite_module();
 
    // now we are all armed up.
    t_idScriptMap::const_iterator iter;
-   ListElement *order;
+   ListElement *order = 0;
 
    if( opt_testList.empty() )
       iter = scriptMap.begin();
@@ -944,7 +894,7 @@ void executeTests( FlcLoader *modloader, Module *rtl )
          s_validAlloc = 1;
       }
 
-      bool success = testScript( script, modloader, core, rtl, testSuite, reason, trace );
+      bool success = testScript( script, modloader, core, testSuite, reason, trace );
 
       if ( success )
       {
@@ -1044,6 +994,12 @@ void executeTests( FlcLoader *modloader, Module *rtl )
 
 int main( int argc, char *argv[] )
 {
+   // Install a void ctrl-c handler (let ctrl-c to kill this app)
+   Sys::_dummy_ctrl_c_handler();
+
+   EngineData data1;
+   Init( data1 );
+
    stdOut = stdOutputStream();
    stdErr = stdErrorStream();
 
@@ -1091,6 +1047,8 @@ int main( int argc, char *argv[] )
    double appTime;
    if( opt_timings )
       appTime = Sys::_seconds();
+   else
+      appTime = 0.0;
 
    FlcLoader *modloader = new FlcLoader( opt_libpath );
    modloader->addFalconPath();
@@ -1101,13 +1059,6 @@ int main( int argc, char *argv[] )
    modloader->compileViaAssembly( opt_compasm );
    modloader->sourceEncoding( "utf-8" );
 
-   Module *falcon_rtl = modloader->loadName( "falcon_rtl" );
-   if ( falcon_rtl == 0 )
-   {
-      stdErr->writeString( "faltest: FATAL - can't find falcon_rtl module.\n" );
-      exit(1);
-   }
-
    int32 error;
    if ( opt_path == "" )
       opt_path = ".";
@@ -1174,12 +1125,14 @@ int main( int argc, char *argv[] )
       return 0;
    }
 
+   // ensure correct accounting by removing extra data.
+   modloader->compiler().reset();
 
-
+   // reset memory tests
    s_totalMem = 0;
    s_totalOutBlocks = 0;
-   executeTests( modloader, falcon_rtl );
 
+   executeTests( modloader );
 
    // in context to have it destroyed on exit
    {
