@@ -22,19 +22,27 @@
 #include <falcon/memory.h>
 #include <falcon/vm.h>
 #include <string.h>
+#include <falcon/lineardict.h>
+#include <falcon/coretable.h>
 
 namespace Falcon {
 
 CoreArray::CoreArray( VMachine *vm ):
+   Garbageable( vm, sizeof( CoreArray ) ),
    m_alloc(0),
    m_size(0),
    m_data(0),
-   Garbageable( vm, sizeof( CoreArray ) )
+   m_bindings(0),
+   m_table(0),
+   m_tablePos(0)
 {}
 
 
 CoreArray::CoreArray( VMachine *vm, uint32 prealloc ):
-   Garbageable( vm, esize(prealloc) + sizeof(CoreArray) )
+   Garbageable( vm, esize(prealloc) + sizeof(CoreArray) ),
+   m_bindings(0),
+   m_table(0),
+   m_tablePos(0)
 {
    m_data = (Item *) memAlloc( esize(prealloc) );
    m_alloc = prealloc;
@@ -42,7 +50,10 @@ CoreArray::CoreArray( VMachine *vm, uint32 prealloc ):
 }
 
 CoreArray::CoreArray( VMachine *vm, Item *buffer, uint32 size, uint32 alloc ):
-   Garbageable( vm, esize(alloc) + sizeof(CoreArray) )
+   Garbageable( vm, esize(alloc) + sizeof(CoreArray) ),
+   m_bindings(0),
+   m_table(0),
+   m_tablePos(0)
 {
    m_data = buffer;
    m_alloc = alloc;
@@ -71,6 +82,9 @@ void CoreArray::append( const Item &ndata )
 
 void CoreArray::merge( const CoreArray &other )
 {
+   if ( m_table != 0 )
+      return;
+
    if ( other.m_size == 0 )
       return;
 
@@ -86,6 +100,9 @@ void CoreArray::merge( const CoreArray &other )
 
 void CoreArray::prepend( const Item &ndata )
 {
+   if ( m_table != 0 )
+      return;
+
    // create enough space to hold the data
    Item *mem = (Item *) memAlloc( esize(m_size + 1) );
    m_alloc = m_size + 1;
@@ -100,6 +117,9 @@ void CoreArray::prepend( const Item &ndata )
 
 void CoreArray::merge_front( const CoreArray &other )
 {
+   if ( m_table != 0 )
+      return;
+
    if ( other.m_size == 0 )
       return;
 
@@ -125,6 +145,9 @@ void CoreArray::merge_front( const CoreArray &other )
 
 bool CoreArray::insert( const Item &ndata, int32 pos )
 {
+   if ( m_table != 0 )
+      return false;
+
    if ( pos < 0 )
       pos = m_size + pos;
    if ( pos < 0 || pos > (int32) m_size )
@@ -155,6 +178,9 @@ bool CoreArray::insert( const Item &ndata, int32 pos )
 
 bool CoreArray::insert( const CoreArray &other, int32 pos )
 {
+   if ( m_table != 0 )
+      return false;
+
    if ( other.m_size == 0 )
       return true;
 
@@ -191,25 +217,29 @@ bool CoreArray::insert( const CoreArray &other, int32 pos )
 
 bool CoreArray::remove( int32 first, int32 last )
 {
+   if ( m_table != 0 )
+      return false;
+
    if ( first < 0 )
       first = m_size + first;
    if ( first < 0 || first >= (int32)m_size )
       return false;
 
    if ( last < 0 )
-      last = m_size + last + 1;
-   if ( last < 0 || last >= (int32)m_size )
+      last = m_size + last;
+   if ( last < 0 || last > (int32)m_size )
       return false;
 
    if( first > last ) {
       int32 temp = first;
       first = last;
-      last = temp;
+      // last can't be < first if it was == size.
+      last = temp+1;
    }
 
-   uint32 rsize = last - first + 1;
-   if ( last < (int32)m_size - 1 )
-      memmove( m_data + first, m_data + last + 1, esize(m_size - last) );
+   uint32 rsize = last - first;
+   if ( last < (int32)m_size )
+      memmove( m_data + first, m_data + last, esize(m_size - last) );
    m_size -= rsize;
    return true;
 }
@@ -228,6 +258,9 @@ int32 CoreArray::find( const Item &itm ) const
 
 bool CoreArray::remove( int32 first )
 {
+   if ( m_table != 0 )
+      return false;
+
    if ( first < 0 )
       first = m_size + first;
    if ( first < 0 || first >= (int32)m_size )
@@ -247,18 +280,20 @@ bool CoreArray::change( const CoreArray &other, int32 begin, int32 end )
       return false;
 
    if ( end < 0 )
-      end = m_size + end + 1;
+      end = m_size + end;
    if ( end < 0 || end > (int32)m_size )
       return false;
 
    if( begin > end ) {
       int32 temp = begin;
       begin = end;
-      end = temp;
+      end = temp+1;
    }
 
    int32 rsize = end - begin;
 
+   // we're considering end as "included" from now on.
+   // this considers also negative range which already includes their extreme.
    if ( m_size - rsize + other.m_size > m_alloc )
    {
       m_alloc =  m_size - rsize +other.m_size;
@@ -289,6 +324,9 @@ bool CoreArray::change( const CoreArray &other, int32 begin, int32 end )
 
 bool CoreArray::insertSpace( uint32 pos, uint32 size )
 {
+   if ( m_table != 0 )
+      return false;
+
    if ( size == 0 )
       return true;
 
@@ -337,7 +375,7 @@ CoreArray *CoreArray::partition( int32 start, int32 end ) const
       return 0;
 
    if ( end < 0 )
-      end = m_size + end + 1;
+      end = m_size + end;
    if ( end < 0 || end > (int32)m_size )
       return 0;
 
@@ -364,7 +402,16 @@ CoreArray *CoreArray::clone() const
 {
    Item *buffer = (Item *) memAlloc( esize( m_size ) );
    memcpy( buffer, m_data, esize( m_size )  );
-   return new CoreArray( origin(), buffer, m_size, m_size );
+   CoreArray *ca = new CoreArray( origin(), buffer, m_size, m_size );
+   ca->m_table = m_table;
+   ca->m_tablePos = m_tablePos;
+
+   if ( m_bindings != 0 )
+   {
+      ca->m_bindings = m_bindings->clone();
+   }
+
+   return ca;
 }
 
 
@@ -394,6 +441,68 @@ void CoreArray::reserve( uint32 size ) {
    }
 }
 
+CoreDict *CoreArray::makeBindings()
+{
+   if ( m_bindings == 0 )
+   {
+      m_bindings = new LinearDict( origin() );
+      m_bindings->insert( new GarbageString( origin(), "self" ), this );
+   }
+
+   return m_bindings;
+}
+
+Item* CoreArray::getProperty( const String &name )
+{
+   Item *found = 0;
+
+   if ( m_bindings != 0 )
+   {
+      found = m_bindings->find( const_cast<String *>(&name) );
+   }
+
+   if ( found == 0 && m_table )
+   {
+      CoreTable *table = reinterpret_cast<CoreTable *>(m_table->getUserData() );
+      uint32 pos = table->getHeaderPos( name );
+      if ( pos != CoreTable::noitem )
+      {
+         found = (*this)[pos].dereference();
+         if ( found->isNil() && ! found->isOob() )
+            found = table->getHeaderData( pos )->dereference();
+
+      }
+   }
+
+   return found;
+}
+
+void CoreArray::setProperty( const String &name, Item &data )
+{
+   if ( m_bindings != 0 )
+   {
+      Item* found = m_bindings->find( const_cast<String *>(&name) );
+      if ( found != 0 ) {
+         *found = data;
+         return;
+      }
+   }
+
+   if ( m_table != 0 )
+   {
+      CoreTable *table = reinterpret_cast<CoreTable *>(m_table->getUserData() );
+      uint32 pos = table->getHeaderPos( name );
+      if ( pos != CoreTable::noitem )
+      {
+         *(*this)[pos].dereference() = data;
+         return;
+      }
+   }
+
+   m_bindings = makeBindings();
+   m_bindings->insert( new GarbageString( origin(), name ), data );
+}
+
 }
 
 /* end of corearray.cpp */
