@@ -1,22 +1,16 @@
 /*
    FALCON - The Falcon Programming Language
    FILE: deferrorhandler.cpp
-   $Id: deferrorhandler.cpp,v 1.6 2007/03/08 14:31:44 jonnymind Exp $
 
    Short description
    -------------------------------------------------------------------
    Author: Giancarlo Niccolai
    Begin: ven ago 25 2006
-   Last modified because:
 
    -------------------------------------------------------------------
    (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)
 
    See LICENSE file for licensing details.
-   In order to use this file in its compiled form, this source or
-   part of it you have to read, understand and accept the conditions
-   that are stated in the LICENSE file that comes boundled with this
-   package.
 */
 
 /** \file
