@@ -38,7 +38,7 @@ const char *en_table[] =
       "Assignment to a constant",
       "Assignment to a non assignable symbol",
       //10
-      "Repeated symbol in declaration",
+      "Non-staitc method called statically",
       "Global statement not inside a function",
       "Symbol already defined",
       "Non callable symbol called",
@@ -65,7 +65,7 @@ const char *en_table[] =
       "Switch directive was already pending",
       "Case directive is not in a switch",
       "Switch not open and .end_switch requested",
-      "Directive .state out of function",
+      "Inconsistent or invalid state",
       "Property definition outside class",
       "Property definition after init definition",
       "Property already defined",
@@ -186,6 +186,8 @@ const char *en_table[] =
       "Syntax error in fast print statement",
       "Syntax error in directive",
       "Syntax error in import statement",
+      "Syntax error in macro definition",
+      "Syntax error in macro call",
 
       "New line in literal string",
       "Duplicate type identifier in catch selector",
@@ -205,6 +207,8 @@ const char *en_table[] =
       "Target class cannot be instantiated",
       "Object cannot be serialized (because of inner native data)",
       "VM received a suspension request in an atomic operation",
+      "Inheritance from more than one subtree of reflected classes.",
+      "Tried to write a read-only property.",
 
       "Can't open file",
       "Load error",
@@ -223,9 +227,6 @@ const char *en_table[] =
       "Parse error in format specifier",
 
       "Unrecognized error code",
-
-      "requres an object and a string representing a property, plus the new value",
-      "parameter array contains non string elements" ,
       0
    };
 
