@@ -30,25 +30,28 @@ namespace Falcon {
 
 
 AsmLexer::AsmLexer( Module *mod, AsmCompiler *cmp, Stream *in ):
-      m_module( mod ),
-      m_in( in ),
-      m_line( 1 ),
-      m_prev_stat(0),
       m_value(0),
+      m_line( 1 ),
       m_character( 0 ),
+      m_prev_stat(0),
+
+      m_module( mod ),
       m_compiler( cmp ),
+      m_in( in ),
       m_done( false ),
-      m_state( e_line ),
       m_bDirective( true ),
+
       m_rega( Pseudo::tregA, false),
       m_regb( Pseudo::tregB, false ),
       m_regs1( Pseudo::tregS1, false ),
       m_regs2( Pseudo::tregS2, false ),
-      m_regl1( Pseudo::tregL1, false ),
+   	m_regl1( Pseudo::tregL1, false ),
       m_regl2( Pseudo::tregL2, false ),
       m_nil( Pseudo::tnil, false ),
       m_true( Pseudo::imm_true, false ),
-      m_false( Pseudo::imm_false, false )
+      m_false( Pseudo::imm_false, false ),
+
+      m_state( e_line )
 {}
 
 int AsmLexer::lex()
@@ -454,6 +457,25 @@ int AsmLexer::lex()
                   return SYMBOL;
                }
 
+               // Is this a late binding?
+               if ( m_string.getCharAt( 0 ) == '&' )
+               {
+                  if ( m_string.length() > 1 )
+                  {
+                     String symname( m_string, 1, m_string.length() );
+
+                     // return also if zero, as no one is gonna read it after an error.
+                     *VALUE = new Falcon::Pseudo( m_line,
+                        Falcon::Pseudo::tlbind,
+                        (Falcon::String *) m_compiler->addString(symname), false );
+                     return SYMBOL;
+                  }
+                  else {
+                     *VALUE = regA_Inst();
+                     return REG_A;
+                  }
+               }
+
                // else, it's a name
                if ( m_bDirective )
                {
@@ -818,6 +840,10 @@ int AsmLexer::checkTokens()
              return I_STEX;
          if ( m_string.compareIgnoreCase( "TRAC" ) == 0 )
              return I_TRAC;
+         if ( m_string.compareIgnoreCase( "FORB" ) == 0 )
+             return I_FORB;
+         if ( m_string.compareIgnoreCase( "EVAL" ) == 0 )
+             return I_EVAL;
       break;
 
    }
@@ -863,6 +889,8 @@ int AsmLexer::checkDirectives()
       case 5:
          if ( m_string == "const" )
             return DCONST;
+         if ( m_string == "alias" )
+            return DALIAS;
          if ( m_string == "local" )
             return DLOCAL;
          if ( m_string == "param" )
@@ -878,6 +906,8 @@ int AsmLexer::checkDirectives()
       case 6:
          if ( m_string == "global" )
             return DGLOBAL;
+         if ( m_string == "import" )
+            return DIMPORT;
          if ( m_string == "attrib" )
             return DATTRIB;
          if ( m_string == "method" )
