@@ -24,7 +24,7 @@
 
 extern "C" void _perform_FALCON_assert_func( const char *expr, const char *filename, int line, const char *funcName )
 {
-   printf( "FALCON ASSERTION FALIED.\n%s:%d in function %s ---\n%s\nProgram ending.\n", filename, funcName, expr, line );
+   printf( "FALCON ASSERTION FALIED.\n%s:%d in function %s ---\n%s\nProgram ending.\n", filename, line, funcName, expr );
    exit(1);
 }
 
