@@ -39,16 +39,39 @@ FlcLoader::FlcLoader( const String &path ):
       m_viaAssembly( false ),
       m_saveModule( true ),
       m_sourceIsAssembly( false ),
-      m_compileErrors(0),
-      m_delayRaise( false ),
+
       m_saveMandatory( false ),
       m_detectTemplate( true ),
-      m_forceTemplate( false )
+      m_forceTemplate( false ),
+
+      m_delayRaise( false ),
+      m_compileErrors(0)
 {
    // we accept sources ( by default)
    m_acceptSources = true;
 }
 
+FlcLoader::FlcLoader( const FlcLoader &other ):
+      ModuleLoader( other ),
+      m_alwaysRecomp( other.m_alwaysRecomp ),
+      m_compMemory( other.m_compMemory ),
+      m_viaAssembly( other.m_viaAssembly ),
+      m_saveModule( other.m_saveModule ),
+      m_sourceIsAssembly( other.m_sourceIsAssembly ),
+
+      m_saveMandatory( other.m_saveMandatory ),
+      m_detectTemplate( other.m_detectTemplate ),
+      m_forceTemplate( other.m_forceTemplate ),
+
+      m_delayRaise( other.m_delayRaise ),
+      m_compileErrors(0)
+{
+}
+
+ModuleLoader *FlcLoader::clone() const
+{
+   return new FlcLoader( *this );
+}
 
 Stream *FlcLoader::openResource( const String &path, t_filetype type )
 {
@@ -218,7 +241,7 @@ Module *FlcLoader::loadSource( Stream *fin, const String &path )
          bDelFin = true;
          fin = temp_binary;
 
-         // as the output stream will be a text, use a text ranscoder.
+         // as the output stream will be a text, use a text transcoder.
          temp_binary = DefaultTextTranscoder( temp_binary, true );
 
          // generate.
@@ -234,9 +257,8 @@ Module *FlcLoader::loadSource( Stream *fin, const String &path )
          temp_binary->seekBegin(0);
       }
       else {
-         GenCode codeOut( temp_binary );
+         GenCode codeOut( module );
          codeOut.generate( m_compiler.sourceTree() );
-         module->setLineInfo( codeOut.extractLineInfo() );
       }
    }
 
@@ -265,7 +287,7 @@ Module *FlcLoader::loadSource( Stream *fin, const String &path )
 
       module = new Module();
 
-      AsmCompiler fasm( module, fin, temp_binary );
+      AsmCompiler fasm( module, fin );
       fasm.errorHandler( m_errhand );
       if ( ! fasm.compile() )
       {
@@ -280,20 +302,11 @@ Module *FlcLoader::loadSource( Stream *fin, const String &path )
 
 
    // import the binary stream in the module;
-   uint64 len = temp_binary->seekEnd( 0 );
-   Falcon::byte *code = (Falcon::byte *) memAlloc( (uint32) len );
-   module->code( code );
-   module->codeSize( (uint32) len );
-   temp_binary->seekBegin( 0 );
-   temp_binary->read( code, (int32) len );
 
    delete temp_binary;
    if( bDelFin )
       delete fin;
 
-   if ( module != 0 )
-      module->addMain();
-
    return module;
 }
 
