@@ -24,6 +24,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <cstring>
+#include <string.h>
 
 #include <falcon/autocstring.h>
 #include <falcon/vm_sys_posix.h>
@@ -51,6 +52,12 @@ GenericStream::GenericStream( const GenericStream &other ):
    m_fsData = other.m_fsData->dup();
 }
 
+GenericStream::~GenericStream()
+{
+   close();
+   delete m_fsData;
+}
+
 bool GenericStream::close()
 {
    UnixFileSysData *data = static_cast< UnixFileSysData *>( m_fsData );
@@ -136,6 +143,8 @@ int64 GenericStream::seek( int64 pos, e_whence whence )
       case ew_begin: from = SEEK_SET; break;
       case ew_cur: from = SEEK_CUR; break;
       case ew_end: from = SEEK_END; break;
+      default:
+         from = SEEK_SET;
    }
 
    pos = (int64) lseek( data->m_handle, pos, from );
@@ -197,7 +206,6 @@ bool GenericStream::errorDescription( ::Falcon::String &description ) const
    if ( data->m_lastError == 0 )
       return false;
 
-   char *buffer;
    const char *error;
 
    if ( data->m_lastError == -1 )
@@ -263,7 +271,7 @@ bool GenericStream::readString( String &content, uint32 size )
    // TODO OPTIMIZE
    uint32 chr;
    content.size( 0 );
-   UnixFileSysData *data = static_cast< UnixFileSysData *>( m_fsData );
+   //UnixFileSysData *data = static_cast< UnixFileSysData *>( m_fsData );
 
    while( size > 0 && get( chr ) )
    {
@@ -398,7 +406,7 @@ int32 GenericStream::writeAvailable( int32 msec, const Sys::SystemData *sysData
    return 0;
 }
 
-UserData *GenericStream::clone() const
+FalconData *GenericStream::clone() const
 {
    GenericStream *ge = new GenericStream( *this );
    if ( ge->m_fsData == 0 )
