@@ -5,7 +5,7 @@
    Generate Falcon Assembly from a Falcon syntactic tree.
    -------------------------------------------------------------------
    Author: Giancarlo Niccolai
-   Begin: $DATE
+   Begin:
 
    -------------------------------------------------------------------
    (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)
@@ -151,16 +151,6 @@ void GenHAsm::gen_class( const StmtClass *cls )
       const InheritDef *id = (const InheritDef *) it_elem->data();
       const Symbol *parent = id->base();
       m_out->writeString( ".inherit $" + parent->name() );
-      ListElement *param_elem = id->parameters().begin();
-      while( param_elem != 0 )
-      {
-         m_out->writeString( " " );
-         const VarDef *vd = (const VarDef*) param_elem->data(); // WARNING, must be const...
-         gen_propdef( *vd ); // or the copy destructor will mess it up
-         param_elem = param_elem->next();
-         if( param_elem != 0 )
-            m_out->writeString( "," );
-      }
       m_out->writeString( "\n" );
       it_elem = it_elem->next();
    }
@@ -250,19 +240,25 @@ void GenHAsm::gen_propdef( const VarDef &def )
       break;
       case VarDef::t_reference:
       case VarDef::t_symbol: m_out->writeString( "$" + def.asSymbol()->name() ); break;
+
+      default:
+         break;
    }
 }
 
 void GenHAsm::gen_depTable( const Module *mod )
 {
-   uint32 count = 0;
-   ListElement *iter = mod->dependencies().begin();
+   MapIterator iter = mod->dependencies().begin();
 
-   while( iter != 0 )
+   while( iter.hasCurrent() )
    {
-      const String *val = (const String *) iter->data();
-      m_out->writeString( ".load " + *val + "\n" );
-      iter = iter->next();
+      const ModuleDepData *depdata = *(const ModuleDepData **) iter.currentValue();
+
+      // only generate non-private data
+      if ( ! depdata->isPrivate() )
+         m_out->writeString( ".load " + *depdata->moduleName() + "\n" );
+
+      iter.next();
    }
 }
 
@@ -297,8 +293,46 @@ void GenHAsm::gen_symbolTable( const Module *mod )
 
       switch( sym->type() ) {
          case Symbol::tundef:
-            temp =  ".extern " + sym->name() + " ";
-            temp.writeNumber( (int64) sym->declaredAt() );
+            // see if it's imported
+            if ( sym->imported() )
+            {
+               // see if we have a namespace into which import it
+               uint32 dotpos = sym->name().rfind( "." );
+               if( dotpos != String::npos )
+               {
+                  String modname = sym->name().subString( 0, dotpos );
+                  String symname = sym->name().subString( dotpos + 1 );
+
+                  temp =  ".import " + symname + " ";
+                  temp.writeNumber( (int64) sym->declaredAt() );
+
+                  ModuleDepData *depdata = mod->dependencies().findModule( modname );
+                  // We have created the module, the entry must be there.
+                  fassert( depdata != 0 );
+                  if ( depdata->isFile() )
+                  {
+                     if( *depdata->moduleName() == modname )
+                        temp += " \"" + modname+"\"";
+                     else
+                        temp += " \"" + *depdata->moduleName() +"\" "+ modname;
+                  }
+                  else
+                  {
+                     if( *depdata->moduleName() == modname )
+                        temp += " " + modname;
+                     else
+                        temp += " " + *depdata->moduleName() +" "+ modname;
+                  }
+               }
+               else {
+                  temp =  ".import " + sym->name() + " ";
+                  temp.writeNumber( (int64) sym->declaredAt() );
+               }
+            }
+            else {
+               temp =  ".extern " + sym->name() + " ";
+               temp.writeNumber( (int64) sym->declaredAt() );
+            }
             m_out->writeString( temp );
          break;
 
@@ -349,6 +383,24 @@ void GenHAsm::gen_symbolTable( const Module *mod )
             m_out->writeString( temp );
          break;
 
+         case Symbol::timportalias:
+            {
+               ImportAlias* ia = sym->getImportAlias();
+               temp =  ".alias " + *ia->name() + " ";
+               temp.writeNumber( (int64) sym->declaredAt() );
+               temp.append( " " );
+               if ( ia->isOrigFileName() ) temp.append( "\"" );
+               temp.append( *ia->origModule() );
+               if ( ia->isOrigFileName() ) temp.append( "\"" );
+               temp.append( " " );
+               temp.append( sym->name() );
+            }
+            m_out->writeString( temp );
+         break;
+
+         default:
+            break;
+
       }
 
       if ( sym->exported() && ! sym->isUndefined() )
@@ -375,8 +427,8 @@ void GenHAsm::gen_function( const StmtFunction *func )
 
    // generate the local symbol table.
    const FuncDef *fd = func->symbol()->getFuncDef();
-   GenericVector params( &traits::t_voidp );
-   GenericVector locals( &traits::t_voidp );
+   GenericVector params( &traits::t_voidp() );
+   GenericVector locals( &traits::t_voidp() );
 
    params.resize( fd->symtab().size() );
    locals.resize( fd->symtab().size() );
@@ -395,6 +447,9 @@ void GenHAsm::gen_function( const StmtFunction *func )
             locals.set( sym, sym->itemId() );
 
          break;
+
+         default:
+            break;
       }
 
       iter.next();
@@ -414,30 +469,14 @@ void GenHAsm::gen_function( const StmtFunction *func )
          m_out->writeString( ".local " + sym->name() + "\n" );
    }
 
-   // generates INST for constructors
+   // generates INIT for constructors
    if ( ctorFor != 0 )
    {
-      const ClassDef *cd = ctorFor->symbol()->getClassDef();
-      ListElement *it_iter = cd->inheritance().begin();
+      ListElement *it_iter = ctorFor->initExpressions().begin();
       while( it_iter != 0 )
       {
-         const InheritDef *id = (const InheritDef *) it_iter->data();
-         const Symbol *parent = id->base();
-         ListElement *param_iter = id->parameters().begin();
-         int count = 0;
-         while( param_iter != 0 )
-         {
-            m_out->writeString( "\tPUSH\t" );
-            const VarDef *vd = (const VarDef*) param_iter->data();
-            gen_propdef( *vd );
-            m_out->writeString( "\n" );
-            param_iter = param_iter->next();
-            count++;
-         }
-         String strcount;
-         strcount.writeNumber( (int64) count );
-         m_out->writeString( "\tINST\t" + strcount + ", $" + parent->name() + "\n" );
-
+         const Value *value = (const Value *) it_iter->data();
+         gen_value( value );
          it_iter = it_iter->next();
       }
    }
@@ -470,7 +509,7 @@ void GenHAsm::gen_function( const StmtFunction *func )
       }
    }
 
-
+   m_out->writeString( ".endfunc\n\n" );
    m_functions.popBack();
 }
 
@@ -1252,6 +1291,9 @@ void GenHAsm::gen_statement( const Statement *stmt )
          m_out->writeString( "_branch_try_end_" + branchStr + ":\n" );
       }
       break;
+
+      default:
+         break;
    }
 }
 
@@ -1538,6 +1580,10 @@ void GenHAsm::gen_operand( const Value *stmt )
       }
       break;
 
+      case Value::t_lbind:
+         m_out->writeString( "&"+ *stmt->asLBind() );
+      break;
+
       case Value::t_imm_bool:
          m_out->writeString( stmt->asBool() ? "T" : "F" );
       break;
@@ -1583,11 +1629,14 @@ void GenHAsm::gen_expression( const Expression *exp, t_valType &xValue )
 {
 
    String opname;
-   int mode; // 1 = unary, 2 = binary
+   int mode = 0; // 1 = unary, 2 = binary
 
    // first, deterime the operator name and operation type
    switch( exp->type() )
    {
+      case Expression::t_none:
+         return;
+
       // optimized away operations
       case Expression::t_optimized:
          gen_value( exp->first() );
@@ -1669,6 +1718,7 @@ void GenHAsm::gen_expression( const Expression *exp, t_valType &xValue )
       case Expression::t_bin_not: mode = 1; opname = "BNOT"; break;
       case Expression::t_strexpand: mode = 1; opname = "STEX"; break;
       case Expression::t_indirect: mode = 1; opname = "INDI"; break;
+      case Expression::t_eval: mode = 1; opname = "EVAL"; break;
 
       case Expression::t_bin_and: mode = 2; opname = "BAND"; break;
       case Expression::t_bin_or: mode = 2; opname = "BOR "; break;
@@ -1749,6 +1799,8 @@ void GenHAsm::gen_expression( const Expression *exp, t_valType &xValue )
       }
       return;
 
+      case Expression::t_fbind: mode = 2; opname = "FORB"; break;
+
       case Expression::t_assign:
          // handle it as a load...
          // don't change x-value
@@ -1810,10 +1862,10 @@ void GenHAsm::gen_expression( const Expression *exp, t_valType &xValue )
          gen_autoassign( "SHRS", exp->first(), exp->second() );
          return;
 
-      case Expression::t_pre_inc: gen_inc_prefix( exp->first() ); return;
-      case Expression::t_pre_dec: gen_dec_prefix( exp->first() ); return;
-      case Expression::t_post_inc: gen_inc_postfix( exp->first() ); return;
-      case Expression::t_post_dec: gen_dec_postfix( exp->first() ); return;
+      case Expression::t_pre_inc: xValue = l_value; gen_inc_prefix( exp->first() ); return;
+      case Expression::t_pre_dec: xValue = l_value; gen_dec_prefix( exp->first() ); return;
+      case Expression::t_post_inc: xValue = l_value; gen_inc_postfix( exp->first() ); return;
+      case Expression::t_post_dec: xValue = l_value; gen_dec_postfix( exp->first() ); return;
 
       case Expression::t_obj_access:
          xValue = p_value;
@@ -1845,6 +1897,34 @@ void GenHAsm::gen_expression( const Expression *exp, t_valType &xValue )
          m_out->writeString( "\tSTO \tA, $" + exp->first()->asSymbol()->name() + "\n" );
       }
       return;
+      
+      case Expression::t_oob:
+         xValue = l_value;
+         m_out->writeString( "\tOOB  \t1, " );
+            gen_operand( exp->first() );
+            m_out->writeString( "\n" );
+      return;
+      
+      case Expression::t_deoob:
+         xValue = l_value;
+         m_out->writeString( "\tOOB  \t0, " );
+            gen_operand( exp->first() );
+            m_out->writeString( "\n" );
+      return;
+      
+      case Expression::t_xoroob:
+         xValue = l_value;
+         m_out->writeString( "\tOOB  \t2, " );
+            gen_operand( exp->first() );
+            m_out->writeString( "\n" );
+      return;
+      
+      case Expression::t_isoob:
+         xValue = l_value;
+         m_out->writeString( "\tOOB  \t3, " );
+            gen_operand( exp->first() );
+            m_out->writeString( "\n" );
+      return;
    }
 
    // post-processing unary and binary operators.
