@@ -64,7 +64,6 @@ void GenTree::generate( const SourceTree *st )
             gen_block( func->staticBlock(), 1 );
          }
 
-         m_out->writeString( "PROLOGUE:\n" );
          gen_block( func->statements(), 1 );
 
          func = static_cast<const StmtFunction *>(func->next());
@@ -528,6 +527,12 @@ void GenTree::gen_value( const Value *val )
       }
       break;
 
+      case Value::t_lbind:
+      {
+         m_out->writeString( "&" + *val->asLBind() );
+      }
+      break;
+
       case Value::t_imm_num: {
          String numStr;
          numStr.writeNumber( val->asInteger() );
@@ -575,6 +580,9 @@ void GenTree::gen_value( const Value *val )
       case Value::t_expression:
          gen_expression( val->asExpr() );
       break;
+
+      default:
+         break;
    }
 }
 
@@ -594,6 +602,12 @@ void GenTree::gen_expression( const Expression *exp )
       case Expression::t_not: type = 0; name = "not"; break;
       case Expression::t_pre_inc: type = 0; name = "++"; break;
       case Expression::t_pre_dec: type = 0; name = "--"; break;
+      
+      case Expression::t_eval: type = 0; name = "^*"; break;
+      case Expression::t_oob: type = 0; name = "^+"; break;
+      case Expression::t_deoob: type = 0; name = "^-"; break;
+      case Expression::t_isoob: type = 0; name = "^?"; break;
+      case Expression::t_xoroob: type = 0; name = "^!"; break;
 
       case Expression::t_post_inc: type = 1; name = "++"; break;
       case Expression::t_post_dec: type = 1; name = "--"; break;
@@ -629,6 +643,7 @@ void GenTree::gen_expression( const Expression *exp )
       case Expression::t_iif: type = 3; break;
 
       case Expression::t_assign: type = 4; name = " = "; break;
+      case Expression::t_fbind: type = 4; name = " | "; break;
       case Expression::t_aadd: type = 4; name = " += "; break;
       case Expression::t_asub: type = 4; name = " -= "; break;
       case Expression::t_amul: type = 4; name = " *= "; break;
@@ -644,8 +659,10 @@ void GenTree::gen_expression( const Expression *exp )
       case Expression::t_array_access: type = 5; break;
       case Expression::t_array_byte_access: type = 10; break;
       case Expression::t_obj_access: type = 6; break;
-      case Expression::t_funcall: type = 7; break;
+      case Expression::t_funcall: case Expression::t_inherit: type = 7; break;
       case Expression::t_lambda: type = 8; break;
+      default:
+         return;
    }
 
    switch( type )
@@ -713,9 +730,9 @@ void GenTree::gen_expression( const Expression *exp )
 
       case 10:
          gen_value( exp->first() );
-         m_out->writeString( "[[ " );
+         m_out->writeString( "[ *" );
          gen_value( exp->second() );
-         m_out->writeString( " ]]" );
+         m_out->writeString( " ]" );
       break;
    }
 }
