@@ -159,6 +159,12 @@ bool LinearDictIterator::insert( const Item &data )
    return false;
 }
 
+FalconData *LinearDictIterator::clone() const
+{
+   return new LinearDictIterator( *this );
+}
+
+
 //=======================================================
 // Iterator
 //
@@ -222,7 +228,7 @@ void LinearDict::last( DictIterator &iter )
 
 
 
-Item *LinearDict::find( const Item &key )
+Item *LinearDict::find( const Item &key ) const
 {
    uint32 posHint;
 
@@ -487,12 +493,21 @@ bool LinearDict::findInternal( const Item &key, uint32 &ret_pos ) const
 
 CoreDict *LinearDict::clone() const
 {
+   LinearDict *ret;
+
    if ( m_size == 0 )
-      return new LinearDict( origin() );
+   {
+      ret = new LinearDict( origin() );
+   }
+   else
+   {
+      ret = new LinearDict( origin(), m_size );
+      ret->length( m_size );
+      memcpy( ret->m_data, m_data, esize( m_size ) );
+   }
+
+   ret->bless( isBlessed() );
 
-   LinearDict *ret = new LinearDict( origin(), m_size );
-   ret->length( m_size );
-   memcpy( ret->m_data, m_data, esize( m_size ) );
    return ret;
 }
 
