@@ -35,6 +35,17 @@ ModuleLoader::ModuleLoader( const String &path ):
    setSearchPath( path );
 }
 
+ModuleLoader::ModuleLoader( const ModuleLoader &other ):
+      m_errhand(other.m_errhand),
+      m_acceptSources( other.m_acceptSources )
+{
+   setSearchPath( other.getSearchPath() );
+}
+
+ModuleLoader *ModuleLoader::clone() const
+{
+   return new ModuleLoader( *this );
+}
 
 void ModuleLoader::getModuleName( const String &path, String &modName )
 {
@@ -189,8 +200,8 @@ ModuleLoader::t_filetype
       ModuleLoader::scanForFile( const String &name, bool isPath,
       ModuleLoader::t_filetype scanForType, String &found, bool accSrc )
 {
-   const char *exts[] = { DllLoader::dllExt(), ".fam", ".fal", ".ftd", 0 };
-   const t_filetype ftypes[] = { t_binmod, t_vmmod, t_source, t_source, t_none };
+   const char *exts[] = { ".ftd", ".fal", ".fam", DllLoader::dllExt(), 0 };
+   const t_filetype ftypes[] = { t_source, t_source, t_vmmod, t_binmod,  t_none };
 
    String path_name;
    String expName = name;
@@ -205,6 +216,10 @@ ModuleLoader::t_filetype
 
    t_filetype tf = t_none;
 
+   // record also a second best, in case we can't load a vm mod
+   String secondBest;
+   t_filetype tf_secondBest = t_none;
+
    ListElement *path_elem = m_path.begin();
    while ( tf == t_none && path_elem != 0 )
    {
@@ -253,6 +268,10 @@ ModuleLoader::t_filetype
                     stats.m_mtime->compare( tsNewest ) > 0
                     )
                {
+                  // record the old candidate
+                  tf_secondBest = tf;
+                  secondBest = found;
+
                   // we found a candidate.
                   tsNewest = *stats.m_mtime;
                   found = temp;
@@ -280,16 +299,22 @@ ModuleLoader::t_filetype
                char ch[4];
                in.read( ch, 4 );
                in.close();
-               if( ch[0] !='F' || ch[1] !='M' ||
-                  ch[2] != FALCON_PCODE_VERSION || ch[3] != FALCON_PCODE_MINOR )
+               if(  ch[0] =='F' && ch[1] =='M' &&
+                          ch[2] == FALCON_PCODE_VERSION &&
+                        ch[3] == FALCON_PCODE_MINOR
+                  )
                {
-                  // try again;
-                  tf = t_none;
+                  // yay, we did it!
+                  break;
                }
             }
-            else {
-               // In the end, we were not even to open it.
-               tf = t_none;
+
+            // nay, back to the old second best (or none)
+            tf = tf_secondBest;
+            if ( tf != t_none )
+            {
+               found = secondBest;
+               break;
             }
          }
       }
@@ -311,30 +336,7 @@ Module *ModuleLoader::loadName( const String &module_name, const String &parent_
    if ( module_name.length() == 0 )
       return 0;
 
-   if ( module_name.getCharAt(0) == '.' )
-   {
-      // notation .name
-      if ( parent_name.size() == 0 )
-         nmodName = module_name.subString( 1 );
-      else {
-         // remove last part of parent name
-         uint32 posDot = parent_name.rfind( "." );
-         // are there no dot? -- we're at root elements
-         if ( posDot == String::npos )
-            nmodName = module_name.subString( 1 );
-         else
-            nmodName = parent_name.subString( 0, posDot ) + module_name; // "." is included.
-      }
-   }
-   else if ( module_name.find( "self." ) == 0 )
-   {
-      if ( parent_name.size() == 0 )
-         nmodName = module_name.subString( 5 );
-      else
-         nmodName = parent_name + "." + module_name.subString( 5 );
-   }
-   else
-      nmodName = module_name;
+   nmodName = Module::relativizeName( module_name, parent_name );
 
    t_filetype type = scanForFile( nmodName, false, t_none, file_path, m_acceptSources );
 
@@ -355,7 +357,6 @@ Module *ModuleLoader::loadName( const String &module_name, const String &parent_
 	{
       mod->name( nmodName );
       mod->path( file_path );
-      mod->addMain();
 
       // should we set a language table?
       if ( m_language != "" && mod->language() != m_language )
@@ -549,7 +550,7 @@ Module *ModuleLoader::loadFile( const String &module_path, t_filetype type, bool
       getModuleName( file_path, modName );
       mod->name( modName );
       mod->path( file_path );
-      mod->addMain();
+
       if ( m_language != "" && mod->language() != m_language )
       {
          loadLanguageTable( mod, m_language );
@@ -583,7 +584,7 @@ Module *ModuleLoader::loadModule( const String &path )
       getModuleName( path, modName );
       mod->name( modName );
       mod->path( path );
-      mod->addMain();
+
       if ( m_language != "" && mod->language() != m_language )
       {
          loadLanguageTable( mod, m_language );
@@ -615,7 +616,7 @@ Module *ModuleLoader::loadSource( const String &path )
       getModuleName( path, modName );
       mod->name( modName );
       mod->path( path );
-      mod->addMain();
+
       if ( m_language != "" && mod->language() != m_language )
       {
          loadLanguageTable( mod, m_language );
