@@ -20,13 +20,13 @@
 #include <falcon/stringstream.h>
 #include <falcon/memory.h>
 #include <cstring>
-
+#include <string.h>
 namespace Falcon {
 
 StringStream::StringStream( int32 size ):
    Stream( t_membuf ),
-   m_allocated( size ),
    m_length( 0 ),
+   m_allocated( size ),
    m_pos( 0 ),
    m_lastError( 0 )
 {
@@ -51,9 +51,7 @@ StringStream::StringStream( int32 size ):
       m_allocated = 0;
       status( t_open );
    }
-
-
-};
+}
 
 StringStream::StringStream( const String &strbuf ):
    Stream( t_membuf ),
@@ -101,6 +99,20 @@ StringStream::StringStream( const StringStream &strbuf ):
    memcpy( m_membuf, strbuf.m_membuf, m_length );
 }
 
+
+void StringStream::transfer( StringStream &strbuf )
+{
+   if ( m_membuf != 0 )
+      memFree( m_membuf );
+
+   status( strbuf.status() );
+   m_length = strbuf.m_length;
+   m_pos = strbuf.m_pos;
+   m_lastError = strbuf.m_lastError;
+   m_allocated = strbuf.m_allocated;
+   m_membuf = strbuf.closeToBuffer();
+}
+
 bool StringStream::errorDescription( String &description ) const
 {
    switch( m_lastError )
@@ -369,7 +381,7 @@ byte * StringStream::closeToBuffer()
    return data;
 }
 
-UserData *StringStream::clone() const
+FalconData *StringStream::clone() const
 {
    StringStream *sstr = new StringStream( *this );
    return sstr;
