@@ -20,6 +20,9 @@
 #include <falcon/stream.h>
 #include <falcon/traits.h>
 
+#include <falcon/falcondata.h>
+#include <falcon/userdata.h>
+
 namespace Falcon
 {
 
@@ -33,6 +36,9 @@ void Symbol::clear()
       case tclass: delete m_value.v_class; break;
       case tprop: delete m_value.v_prop; break;
       case tconst: delete m_value.v_prop; break;
+      case timportalias: delete m_value.v_importalias; break;
+      default:
+         break;
    }
    m_type = tundef;
 }
@@ -79,11 +85,11 @@ bool Symbol::load( Stream *in )
 
    switch( type_t( type ) ) {
       case tfunc:
-         setFunction( new FuncDef( 0 ) );
+         setFunction( new FuncDef( 0, 0 ) );
       return getFuncDef()->load( m_module, in );
 
       case tclass:
-         setClass( new ClassDef( 0, 0 ) );
+         setClass( new ClassDef );
       return getClassDef()->load( m_module, in );
 
       case tvar:
@@ -115,12 +121,27 @@ bool Symbol::load( Stream *in )
       }
       break;
 
+      case timportalias:
+      {
+         in->read( &strid , sizeof( strid ) );
+         strid = endianInt32( strid );
+         const String *name = m_module->getString( strid );
+         in->read( &strid , sizeof( strid ) );
+         strid = endianInt32( strid );
+         const String *origMod = m_module->getString( strid );
+         byte b;
+         in->read( &b, 1 );
+         setImportAlias( name, origMod, b == 1 );
+      }
+      break;
+
       case tundef:
       case tlocal:
       case tparam:
       case tlocalundef:
       case tattribute:
          m_type = type_t( type );
+
       break;
 
       default:
@@ -155,22 +176,96 @@ bool Symbol::save( Stream *out ) const
          strid = endianInt32( getInstance()->id() );
          out->write( &strid, sizeof( strid ) );
       break;
+
+      case timportalias:
+         strid = endianInt32( getImportAlias()->name()->id() );
+         out->write( &strid, sizeof( strid ) );
+         strid = endianInt32( getImportAlias()->origModule()->id() );
+         out->write( &strid, sizeof( strid ) );
+         {
+            byte b = getImportAlias()->isOrigFileName() ? 1 : 0;
+            out->write( &b, 1 );
+         }
+      break;
+
+      default:
+         break;
    }
    return true;
 }
 
 
-FuncDef::FuncDef( uint32 offset ):
-   m_offset( offset ),
+Symbol* Symbol::addParam( const String &param )
+{
+
+   Symbol* tbc = this;
+   if ( isClass() )
+   {
+      tbc = getClassDef()->constructor();
+      if ( tbc == 0 )
+         return this;
+   }
+
+   switch( tbc->m_type ) {
+      case tfunc: tbc->getFuncDef()->addParameter(m_module->addSymbol( param )); break;
+      case textfunc: tbc->getExtFuncDef()->addParam(m_module->addSymbol( param )); break;
+
+      default:
+         return this;
+   }
+
+   return this;
+}
+
+//=================================================================
+//
+int32 ExtFuncDef::getParam( const String &name )
+{
+   if ( m_params == 0 )
+      return -1;
+
+   Symbol *sym = m_params->findByName( name );
+   if ( sym == 0 )
+      return -1;
+   return sym->itemId();
+}
+
+/** Adds a function parameter with the specified ID.
+   Consider using Symbol::addParam() instead (candy grammar).
+*/
+ExtFuncDef &ExtFuncDef::addParam( Symbol *param, int32 id )
+{
+   if ( m_params == 0 )
+      m_params = new SymbolTable;
+
+   param->setParam();
+   param->itemId( id == -1 ? m_params->size() : id );
+   m_params->add( param );
+
+   return *this;
+}
+
+ExtFuncDef::~ExtFuncDef()
+{
+   delete m_params;
+}
+
+//=================================================================
+//
+FuncDef::FuncDef( byte *code, uint32 codeSize ):
+   m_code( code ),
+   m_codeSize( codeSize ),
    m_params( 0 ),
    m_locals( 0 ),
    m_undefined( 0 ),
-   m_onceItemId( NO_STATE )
+   m_onceItemId( NO_STATE ),
+   m_basePC(0)
 {
 }
 
 FuncDef::~FuncDef()
 {
+   memFree( m_code );
 }
 
 Symbol *FuncDef::addParameter( Symbol *sym )
@@ -202,15 +297,23 @@ Symbol *FuncDef::addUndefined( Symbol *sym )
 
 bool FuncDef::save( Stream *out ) const
 {
-   uint32 offset = endianInt32(m_offset);
-   out->write( &offset, sizeof( offset ) );
    uint16 locs = endianInt16( m_locals );
    uint16 params = endianInt16( m_params );
    out->write( &locs, sizeof( locs ) );
    out->write( &params, sizeof( params ) );
 
-   offset = endianInt32(m_onceItemId);
-   out->write( &offset, sizeof( offset ) );
+   uint32 onceId = endianInt32(m_onceItemId);
+   out->write( &onceId, sizeof( onceId ) );
+
+   uint32 basePC = endianInt32(m_basePC);
+   out->write( &basePC, sizeof( basePC ) );
+
+   uint32 codeSize = endianInt32(m_codeSize);
+   out->write( &codeSize, sizeof( codeSize ) );
+   if ( m_codeSize > 0 )
+   {
+      out->write( m_code, m_codeSize );
+   }
 
    return m_symtab.save( out );
 }
@@ -218,54 +321,50 @@ bool FuncDef::save( Stream *out ) const
 
 bool FuncDef::load( Module *mod, Stream *in )
 {
-   uint32 offset;
-   in->read( &offset, sizeof( offset ) );
-   m_offset = endianInt32( offset );
    uint16 loc;
    in->read( &loc, sizeof( loc ) );
    m_locals = endianInt16( loc );
    in->read( &loc, sizeof( loc ) );
    m_params = endianInt16( loc );
 
-   in->read( &offset, sizeof( offset ) );
-   m_onceItemId = endianInt32( offset );
+   uint32 onceItem = 0;
+   in->read( &onceItem, sizeof( onceItem ) );
+   m_onceItemId = endianInt32( onceItem );
+
+   uint32 basePC = 0;
+   in->read( &basePC, sizeof( basePC ) );
+   m_basePC = endianInt32( basePC );
+
+   int32 codeSize = 0;
+   in->read( &codeSize, sizeof( codeSize ) );
+   m_codeSize = endianInt32( codeSize );
+   m_code = 0;
+
+   // it's essential to check for errors now.
+   if ( ! in->good() )
+      return false;
+
+   if ( m_codeSize > 0 )
+   {
+      m_code = (byte *) memAlloc( m_codeSize );
+      in->read( m_code, m_codeSize );
+      // it's essential to check for errors now.
+      if ( ! in->good() )
+         return false;
+   }
 
    return m_symtab.load( mod, in );
 }
 
 InheritDef::~InheritDef()
 {
-   ListElement *iter = m_params.begin();
-   while( iter != 0 ) {
-      VarDef *param = (VarDef *) iter->data();
-      delete param;
-      iter = iter->next();
-   }
 }
 
-
-void InheritDef::addParameter( VarDef *def )
-{
-   //creates a copy of the passed object.
-   m_params.pushBack( def );
-}
-
-
 bool InheritDef::save( Stream *out ) const
 {
    uint32 parentId = endianInt32( m_baseClass->id() );
    out->write( &parentId, sizeof( parentId ) );
 
-   uint32 size = endianInt32( m_params.size() );
-   out->write( &size, sizeof( size ) );
-
-   ListElement *iter = m_params.begin();
-   while( iter != 0 ) {
-      const VarDef *param = (const VarDef *) iter->data();
-      param->save( out );
-      iter = iter->next();
-   }
-
    return true;
 }
 
@@ -278,28 +377,28 @@ bool InheritDef::load( Module *mod, Stream *in )
    if ( m_baseClass == 0 )
       return false;
 
-   uint32 size;
-   in->read(  &size , sizeof( size ) );
-   size = endianInt32( size );
-
-   for( uint32 i = 0; i < size; i++ )
-   {
-      VarDef *vd = new VarDef();
-      m_params.pushBack( vd ); // avoid leak in case of failure.
-      if ( ! vd->load( mod, in ) )
-         return false;
-   }
-
    return true;
 }
 
 
-ClassDef::ClassDef( uint32 offset, Symbol *ext_ctor ):
-   FuncDef( offset ),
-   m_constructor( ext_ctor ),
-   m_properties( &traits::t_stringptr, &traits::t_voidp )
+//=================================================================
+//
+
+ClassDef::ClassDef( ObjectManager *manager ):
+   FuncDef( 0, 0 ),
+   m_constructor( 0 ),
+   m_properties( &traits::t_stringptr(), &traits::t_voidp() ),
+   m_manager( manager )
 {}
 
+ClassDef::ClassDef( Symbol *ext_ctor, ObjectManager *manager ):
+   FuncDef( 0, 0 ),
+   m_constructor( ext_ctor ),
+   m_properties( &traits::t_stringptr(), &traits::t_voidp() ),
+   m_manager( manager )
+{}
+
+
 ClassDef::~ClassDef()
 {
    MapIterator iterp = m_properties.begin();
@@ -516,6 +615,23 @@ bool ClassDef::load( Module *mod, Stream *in )
    return true;
 }
 
+
+void ClassDef::carryUserData() {
+   setObjectManager( &core_user_data_manager_cacheful );
+}
+
+void ClassDef::carryUserDataCacheless() {
+   setObjectManager( &core_user_data_manager_cacheless );
+}
+
+
+void ClassDef::carryFalconData(){
+   setObjectManager( &core_falcon_data_manager );
+}
+
+//===================================================================
+// vardef
+
 bool VarDef::save( Stream *out ) const
 {
    int32 type = endianInt32((int32) m_val_type);
@@ -531,7 +647,6 @@ bool VarDef::save( Stream *out ) const
       break;
 
       case t_int:
-      case t_reflective:
       {
          int64 val = endianInt64( m_value.val_int );
          out->write( &val , sizeof( val ) );
@@ -559,8 +674,12 @@ bool VarDef::save( Stream *out ) const
          uint32 val = endianInt32( asSymbol()->id() );
          out->write( &val , sizeof( val ) );
       }
+
+      default:
+         return true;
    }
-   return true;
+
+   return out->good();
 }
 
 bool VarDef::load( Module *mod, Stream *in )
@@ -582,7 +701,6 @@ bool VarDef::load( Module *mod, Stream *in )
       break;
 
       case t_int:
-      case t_reflective:
       {
          int64 val;
          in->read(   &val , sizeof( val ) );
@@ -618,6 +736,9 @@ bool VarDef::load( Module *mod, Stream *in )
          if ( m_value.val_sym == 0 )
             return false;
       }
+
+      default:
+         break;
    }
    return true;
 }
