@@ -141,8 +141,9 @@ bool Value::isEqualByValue( const Value &other ) const
 
          case Value::t_range_decl:
             if( other.asRange()->rangeStart() == asRange()->rangeStart() &&
-                  ( asRange()->isOpen() && other.asRange()->isOpen() ||
-                    ! asRange()->isOpen() && ! other.asRange()->isOpen() && other.asRange()->rangeEnd() == asRange()->rangeEnd()
+                  ( (asRange()->isOpen() && other.asRange()->isOpen()) ||
+                    (! asRange()->isOpen() && ! other.asRange()->isOpen() 
+                       && other.asRange()->rangeEnd() == asRange()->rangeEnd())
                   )
                )
                return true;
@@ -154,7 +155,12 @@ bool Value::isEqualByValue( const Value &other ) const
          break;
 
          case Value::t_imm_string:
-            if( asString() == other.asString() )
+            if( *asString() == *other.asString() )
+               return true;
+         break;
+
+         case Value::t_lbind:
+            if( *asLBind() == *other.asLBind() )
                return true;
          break;
 
@@ -167,6 +173,9 @@ bool Value::isEqualByValue( const Value &other ) const
             if( asSymdef()->id() == other.asSymdef()->id() )
                return true;
          break;
+
+         default:
+            break;
       }
    }
 
@@ -203,6 +212,11 @@ bool Value::less( const Value &other ) const
                return true;
          break;
 
+         case Value::t_lbind:
+            if( *asLBind() < *other.asLBind() )
+               return true;
+         break;
+
          case Value::t_symbol:
             if( asSymbol()->id() < other.asSymbol()->id() )
                return true;
@@ -212,38 +226,13 @@ bool Value::less( const Value &other ) const
             if( asSymdef()->id() < other.asSymdef()->id() )
                return true;
          break;
+
+         default:
+            break;
       }
    }
    else {
-      int typeval, other_typeval;
-
-      switch( type() )
-      {
-         case Value::t_nil: typeval = 0; break;
-         case Value::t_imm_integer: typeval = 1; break;
-         case Value::t_imm_num: typeval = 2; break;
-         case Value::t_range_decl: typeval = 3; break;
-         case Value::t_imm_string: typeval = 4; break;
-         case Value::t_symbol: typeval = 5; break;
-         case Value::t_symdef: typeval = 6; break;
-         default:
-            return false;
-      }
-
-      switch( other.type() )
-      {
-         case Value::t_nil: other_typeval = 0; break;
-         case Value::t_imm_integer: other_typeval = 1; break;
-         case Value::t_imm_num: other_typeval = 2; break;
-         case Value::t_range_decl: other_typeval = 3; break;
-         case Value::t_imm_string: other_typeval = 4; break;
-         case Value::t_symbol: other_typeval = 5; break;
-         case Value::t_symdef: other_typeval = 6; break;
-         default:
-            return false;
-      }
-
-      return typeval < other_typeval;
+      return ((uint32)type()) < ((uint32)other.type());
    }
 
    return false;
@@ -279,18 +268,6 @@ VarDef *Value::genVarDef()
    return def;
 }
 
-VarDef *Value::genVarDefSym()
-{
-   switch( type() )
-   {
-      case t_symbol:
-         return new VarDef( asSymbol() );
-
-      default:
-         return genVarDef();
-   }
-}
-
 Value::~Value()
 {
    switch( m_type )
@@ -316,8 +293,10 @@ Value::~Value()
          delete m_content.asExpr;
       break;
 
+      default:
       // In every other case, there is nothing to do as strings and symbols are held in the
       // module and are not to be disposed here.
+         break;
    }
 
 }
@@ -393,7 +372,7 @@ bool ValuePtrTraits::owning() const
 
 
 namespace traits {
-   ValuePtrTraits t_valueptr;
+   ValuePtrTraits &t_valueptr() { static ValuePtrTraits dt; return dt; }
 }
 
 //================================================
@@ -743,24 +722,24 @@ Statement *StmtCaseBlock::clone() const
 
 StmtSwitch::StmtSwitch( uint32 line, Value *expr ):
    Statement( line, t_switch ),
+   m_cases_int( &traits::t_valueptr(), &traits::t_int(), 19 ),
+   m_cases_rng( &traits::t_valueptr(), &traits::t_int(), 19 ),
+   m_cases_str( &traits::t_valueptr(), &traits::t_int(), 19 ),
+   m_cases_obj( &traits::t_valueptr(), &traits::t_int(), 19 ),
    m_nilBlock( -1 ),
-   m_cfr( expr ),
-   m_cases_int( &traits::t_valueptr, &traits::t_int, 19 ),
-   m_cases_rng( &traits::t_valueptr, &traits::t_int, 19 ),
-   m_cases_str( &traits::t_valueptr, &traits::t_int, 19 ),
-   m_cases_obj( &traits::t_valueptr, &traits::t_int, 19 )
+   m_cfr( expr )
 {}
 
 StmtSwitch::StmtSwitch( const StmtSwitch &other ):
    Statement( other ),
-   m_nilBlock( other.m_nilBlock ),
    m_cases_int( other.m_cases_int ),
    m_cases_rng( other.m_cases_rng ),
    m_cases_str( other.m_cases_str ),
    m_cases_obj( other.m_cases_obj ),
    m_obj_list( other.m_obj_list ),
    m_blocks( other.m_blocks ),
-   m_defaultBlock( other.m_defaultBlock )
+   m_defaultBlock( other.m_defaultBlock ),
+   m_nilBlock( other.m_nilBlock )
 {
    m_cfr = other.m_cfr == 0 ? 0 : new Value( *other.m_cfr );
 }
@@ -844,7 +823,7 @@ bool StmtSwitch::addRangeCase( Value *itm )
       Value *first = *(Value **) iter.currentKey();
       int32 val = (int32) first->asInteger();
 
-      if ( isOpen && val >= start || !isOpen && val >= start && val <= end )
+      if ( (isOpen && val >= start) || (!isOpen && val >= start && val <= end) )
       {
          return false;
       }
@@ -879,10 +858,10 @@ bool StmtSwitch::addRangeCase( Value *itm )
          }
          else
          {
-            if (  start <= other_start && other_start <= end ||
-                  start <= other_end && other_end <= end ||
-                  other_start <= start && start <= other_end ||
-                  other_start <= end && end <= other_end
+            if ( (start <= other_start && other_start <= end) ||
+                 (start <= other_end && other_end <= end) ||
+                 (other_start <= start && start <= other_end) ||
+                 (other_start <= end && end <= other_end)
             )
                return false;
          }
@@ -965,10 +944,10 @@ Statement *StmtCatchBlock::clone() const
 
 StmtTry::StmtTry( uint32 line ):
    StmtBlock( line, t_try ),
-   m_default(0),
-   m_cases_int( &traits::t_valueptr, &traits::t_int, 13 ),
-   m_cases_sym( &traits::t_valueptr, &traits::t_int, 13 ),
-   m_into_values( s_valueDeletor )
+   m_cases_int( &traits::t_valueptr(), &traits::t_int(), 13 ),
+   m_cases_sym( &traits::t_valueptr(), &traits::t_int(), 13 ),
+   m_into_values( s_valueDeletor ),
+   m_default(0)
 {}
 
 StmtTry::StmtTry( const StmtTry &other ):
