@@ -58,11 +58,11 @@ bool SymModuleTraits::owning() const
 
 namespace traits
 {
-   SymModuleTraits t_symmodule;
+   SymModuleTraits &t_symmodule() { static SymModuleTraits dt; return dt; }
 }
 
 SymModuleMap::SymModuleMap():
-   Map( &traits::t_stringptr, &traits::t_symmodule )
+   Map( &traits::t_stringptr(), &traits::t_symmodule() )
 {}
 
 
@@ -108,17 +108,19 @@ bool LiveModulePtrTraits::owning() const
 
 namespace traits
 {
-   LiveModulePtrTraits t_livemoduleptr;
+   LiveModulePtrTraits &t_livemoduleptr() { static LiveModulePtrTraits dt; return dt; }
 }
 
 LiveModuleMap::LiveModuleMap():
-   Map( &traits::t_string, &traits::t_livemoduleptr )
+   Map( &traits::t_string(), &traits::t_livemoduleptr() )
 {}
 
 
-LiveModule::LiveModule( VMachine *vm, Module *mod ):
+LiveModule::LiveModule( VMachine *vm, Module *mod, bool bPrivate ):
    Garbageable( vm, sizeof( *this ) ),
-   m_module( mod )
+   m_module( mod ),
+   m_bPrivate( bPrivate ),
+   m_initState( init_none )
 {
    m_module->incref();
 }
@@ -134,11 +136,13 @@ void LiveModule::detachModule()
 {
    if ( m_module != 0 )
    {
-      m_module->decref();
+      Module *m = m_module;
       m_module = 0;
       // no reason to keep globals allocated
       m_globals.resize(0);
       m_wkitems.resize(0);
+
+      m->decref();
    }
 }
 
