@@ -29,13 +29,9 @@
 namespace Falcon {
 
 class Item;
+class Bindings;
 
 /** Core array (or array of items).
-
-   Why not just use STL vectors?
-
-   Because 1) this ones must be derived from garbageable, and 2) in future
-   they may be polymorphic (we may have chuncked array).
 */
 
 class FALCON_DYN_CLASS CoreArray: public Garbageable
@@ -43,6 +39,9 @@ class FALCON_DYN_CLASS CoreArray: public Garbageable
    uint32 m_alloc;
    uint32 m_size;
    Item *m_data;
+   CoreDict *m_bindings;
+   CoreObject *m_table;
+   uint32 m_tablePos;
 
    CoreArray( VMachine *vm, Item *buffer, uint32 size, uint32 alloc );
 
@@ -80,6 +79,32 @@ public:
    void resize( uint32 size );
    void reserve( uint32 size );
 
+   /** Create the bindings for this array, or get those already created. */
+   CoreDict *makeBindings();
+   CoreDict *bindings() const { return m_bindings; }
+   void setBindings( CoreDict *binds ) { m_bindings = binds; }
+
+   /** Gets a proprty of this vector.
+      Properties are either bindings or table properties. Bindings
+      override table-wide properties.
+
+      If the given property is not found, 0 is returned.
+      \param name The property to be found.
+      \return the property item if found or zero.
+   */
+   Item* getProperty( const String &name );
+
+   /** Set a property in this array.
+      If there is a biniding with the given property name, that item is updated.
+      If not, If there is a table with a column name, the coresponding item in
+      the array is updated.
+      If not, new bindings are created, and the property is stored as a new binding.
+
+      \param name The property to be updated.
+      \param data The update data.
+   */
+   void setProperty( const String &name, Item &data );
+
    /** Checks the position to be in the array, and eventually changes it if it's negative.
       \param pos the position to be checked and eventually turned into a positive value.
       \return false if pos is outside the array size
@@ -132,6 +157,13 @@ public:
          pos = m_size + pos;
       return m_data[pos];
    }
+
+   CoreObject *table() const { return m_table; }
+   void table( CoreObject *t ) { m_table = t; }
+
+   uint32 tablePos() const { return m_tablePos; }
+   void tablePos( uint32 tp ) { m_tablePos = tp; }
+
 };
 
 }
