@@ -18,8 +18,8 @@
    (this file contains also the TraceStep class).
 */
 
-#ifndef flc_error_H
-#define flc_error_H
+#ifndef FALCON_ERROR_H
+#define FALCON_ERROR_H
 
 #include <falcon/setup.h>
 #include <falcon/types.h>
@@ -27,7 +27,8 @@
 #include <falcon/item.h>
 #include <falcon/genericlist.h>
 #include <falcon/string.h>
-#include <falcon/userdata.h>
+#include <falcon/falcondata.h>
+#include <falcon/reflectfunc.h>
 
 namespace Falcon {
 
@@ -41,7 +42,7 @@ const int e_mod_by_zero =          7;
 const int e_invalid_op =           8;
 const int e_assign_const =         9;
 const int e_assign_sym =           10;
-const int e_repeated =             11;
+const int e_static_call =          11;
 const int e_global_notin_func =    12;
 const int e_already_def =          13;
 const int e_non_callable =         14;
@@ -66,7 +67,7 @@ const int e_too_params =           32;
 const int e_switch_again =         33;
 const int e_switch_case =          34;
 const int e_switch_end =           35;
-const int e_inv_setstate =         36;
+const int e_inv_state =            36;
 const int e_prop_no_class =        37;
 const int e_prop_pinit =           38;
 const int e_prop_adef =            39;
@@ -186,6 +187,8 @@ const int e_syn_fordot =           182;
 const int e_syn_self_print =       183;
 const int e_syn_directive =        184;
 const int e_syn_import =           185;
+const int e_syn_macro =            186;
+const int e_syn_macro_call =       187;
 
 const int e_nl_in_lit =            200;
 const int e_catch_adef =           201;
@@ -205,6 +208,9 @@ const int e_directive_value =      214;
 const int e_noninst_cls =          215;
 const int e_unserializable =       216;
 const int e_wait_in_atomic =       217;
+const int e_inv_inherit2 =         218;
+const int e_prop_ro =              219;
+
 
 const int e_open_file =            500;
 const int e_loaderror =            501;
@@ -360,7 +366,7 @@ class FALCON_DYN_CLASS Error: public BaseAlloc
 {
 protected:
    volatile long m_refCount;
-   
+
    int m_errorCode;
    String m_description;
    String m_extra;
@@ -387,14 +393,14 @@ protected:
       The error must be filled with proper values.
    */
    Error( const String &className ):
+      m_refCount( 1 ),
       m_errorCode ( e_none ),
-      m_sysError( 0 ),
+      m_className( className ),
       m_line( 0 ),
       m_character( 0 ),
       m_pc( 0 ),
+      m_sysError( 0 ),
       m_origin( e_orig_runtime ),
-      m_refCount( 1 ),
-      m_className( className ),
       m_catchable( true ),
       m_nextError( 0 ),
       m_LastNextError( 0 )
@@ -410,19 +416,19 @@ protected:
       for the given error code.
    */
    Error( const String &className, const ErrorParam &params ):
-      m_errorCode ( params.m_errorCode ),
-      m_sysError( params.m_sysError ),
-      m_line( params.m_line ),
-      m_character( params.m_character ),
-      m_pc( params.m_pc ),
-      m_origin( params.m_origin ),
       m_refCount( 1 ),
-      m_className( className ),
-      m_catchable( params.m_catchable ),
+      m_errorCode ( params.m_errorCode ),
       m_description( params.m_description ),
       m_extra( params.m_extra ),
       m_symbol( params.m_symbol ),
       m_module( params.m_module ),
+      m_className( className ),
+      m_line( params.m_line ),
+      m_character( params.m_character ),
+      m_pc( params.m_pc ),
+      m_sysError( params.m_sysError ),
+      m_origin( params.m_origin ),
+      m_catchable( params.m_catchable ),
       m_nextError( 0 ),
       m_LastNextError( 0 )
    {
@@ -435,6 +441,41 @@ protected:
    virtual ~Error();
 public:
 
+   Error():
+      m_refCount( 1 ),
+      m_errorCode ( e_none ),
+      m_className( "Error" ),
+      m_line( 0 ),
+      m_character( 0 ),
+      m_pc( 0 ),
+      m_sysError( 0 ),
+      m_origin( e_orig_runtime ),
+      m_catchable( true ),
+      m_nextError( 0 ),
+      m_LastNextError( 0 )
+   {
+      m_raised.setNil();
+   }
+
+   Error( const ErrorParam &params ):
+      m_refCount( 1 ),
+      m_errorCode ( params.m_errorCode ),
+      m_description( params.m_description ),
+      m_extra( params.m_extra ),
+      m_symbol( params.m_symbol ),
+      m_module( params.m_module ),
+      m_className( "Error" ),
+      m_line( params.m_line ),
+      m_character( params.m_character ),
+      m_pc( params.m_pc ),
+      m_sysError( params.m_sysError ),
+      m_origin( params.m_origin ),
+      m_catchable( params.m_catchable ),
+      m_nextError( 0 ),
+      m_LastNextError( 0 )
+   {
+      m_raised.setNil();
+   }
 
    void errorCode( int ecode ) { m_errorCode = ecode; }
    void systemError( uint32 ecode ) { m_sysError = ecode; }
@@ -504,6 +545,8 @@ public:
 
    void incref();
    void decref();
+
+   virtual Error *clone() const;
 };
 
 
@@ -512,11 +555,11 @@ class GenericError: public Error
 {
 public:
    GenericError():
-      Error( "Error" )
+      Error( "GenericError" )
    {}
 
    GenericError( const ErrorParam &params  ):
-      Error( "Error", params )
+      Error( "GenericError", params )
       {}
 };
 
@@ -642,23 +685,6 @@ public:
 };
 
 
-
-class FALCON_DYN_CLASS ErrorCarrier: public UserData
-{
-   Error *m_error;
-   String m_origin;
-
-public:
-   ErrorCarrier( Error *carried );
-
-   virtual ~ErrorCarrier();
-   virtual bool isReflective() const;
-   virtual void getProperty( VMachine *vm, const String &propName, Item &prop );
-   virtual void setProperty( VMachine *vm, const String &propName, Item &prop );
-
-   Error *error() const { return m_error; }
-};
-
 /** Returns the description of a falcon error.
    In case the error ID is not found, a sensible message will be returned.
 */
@@ -673,8 +699,39 @@ FALCON_FUNC_DYN_SYM AccessError_init ( ::Falcon::VMachine *vm );
 FALCON_FUNC_DYN_SYM MathError_init ( ::Falcon::VMachine *vm );
 FALCON_FUNC_DYN_SYM ParamError_init ( ::Falcon::VMachine *vm );
 FALCON_FUNC_DYN_SYM ParseError_init ( ::Falcon::VMachine *vm );
+
+/** Reflective function to support error property: code */
+extern reflectionFuncDecl Error_code_rfrom;
+extern reflectionFuncDecl Error_description_rfrom;
+extern reflectionFuncDecl Error_message_rfrom;
+extern reflectionFuncDecl Error_systemError_rfrom;
+extern reflectionFuncDecl Error_origin_rfrom;
+extern reflectionFuncDecl Error_module_rfrom;
+extern reflectionFuncDecl Error_symbol_rfrom;
+extern reflectionFuncDecl Error_line_rfrom;
+extern reflectionFuncDecl Error_pc_rfrom;
+
+extern reflectionFuncDecl Error_code_rto;
+extern reflectionFuncDecl Error_description_rto;
+extern reflectionFuncDecl Error_message_rto;
+extern reflectionFuncDecl Error_systemError_rto;
+extern reflectionFuncDecl Error_origin_rto;
+extern reflectionFuncDecl Error_module_rto;
+extern reflectionFuncDecl Error_symbol_rto;
+extern reflectionFuncDecl Error_line_rto;
+extern reflectionFuncDecl Error_pc_rto;
 }
 
+/** Error manager.
+   This manager takes care of decreffing the error on object destruction.
+   ATM it doesn't create an initial error.
+*/
+class ErrorManager: public ObjectManager {
+   virtual void *onInit( VMachine *vm );
+   virtual void onDestroy( VMachine *vm, void *user_data );
+   virtual void *onClone( VMachine *vm, void *user_data );
+};
+
 }
 
 #endif
