@@ -42,6 +42,10 @@ class Stream;
 class Attribute;
 class LiveModule;
 class MemBuf;
+class GarbagePointer;
+class FalconData;
+class CodeError;
+
 
 /** Basic item abstraction.*/
 class FALCON_DYN_CLASS Item: public BaseAlloc
@@ -78,18 +82,7 @@ public:
    e_sercode;
 
 private:
-   union {
-      struct {
-         byte methodId;
-         byte reserved;
-         byte type;
-         byte flags;
-      } bits;
-      uint16 half;
-      uint32 whole;
-   } m_base;
-
-   union {
+  union {
       struct {
          int32 val1;
          int32 val2;
@@ -101,20 +94,36 @@ private:
          void *voidp;
          void *m_extra;
          LiveModule *m_liveMod;
-      };
+      } ptr;
 
       struct {
          int32 rstart;
          int32 rend;
          int32 rstep;
-      };
+      } rng;
 
+      struct {
+         GarbagePointer *gcptr;
+         int32 signature;
+      } gptr;
    } m_data;
 
+   union {
+      struct {
+         byte methodId;
+         byte reserved;
+         byte type;
+         byte flags;
+      } bits;
+      uint16 half;
+      uint32 whole;
+   } m_base;
+
+
 
    bool internal_is_equal( const Item &other ) const;
    int internal_compare( const Item &other ) const;
-   bool serialize_object( Stream *file, const CoreObject *obj, bool bLive ) const;
+   bool serialize_object( Stream *file, CoreObject *obj, bool bLive ) const;
    bool serialize_symbol( Stream *file, const Symbol *sym ) const;
    bool serialize_function( Stream *file, const Symbol *func ) const;
    bool serialize_class( Stream *file, const CoreClass *cls ) const;
@@ -127,13 +136,16 @@ private:
 	#if _MSC_VER < 1299
 	#define flagOpenRange 0x02
 	#define flagIsOob 0x04
+	#define flagFuture 0x08
 	#else
 	   static const byte flagOpenRange = 0x02;
 	   static const byte flagIsOob = 0x04;
+	   static const byte flagFuture = 0x08;
 	#endif
 #else
 	static const byte flagOpenRange = 0x02;
    static const byte flagIsOob = 0x04;
+   static const byte flagFuture = 0x08;
 #endif
 
 public:
@@ -148,7 +160,7 @@ public:
       content( dt );
    }
 
-   Item( Symbol *func, LiveModule *mod )
+   Item( const Symbol *func, LiveModule *mod )
    {
       setFunction( func, mod );
    }
@@ -160,10 +172,6 @@ public:
    }
 
    /** Creates a boolean item. */
-   explicit Item( bool tof )
-   {
-      setBoolean( tof );
-   }
 
    /** Sets this item as boolean */
    void setBoolean( bool tof )
@@ -172,6 +180,31 @@ public:
       m_data.num.val1 = tof?1: 0;
    }
 
+   /** Creates an integer item */
+   Item( int16 val )
+   {
+      setInteger( (int64) val );
+   }
+
+   /** Creates an integer item */
+   Item( uint16 val )
+   {
+      setInteger( (int64) val );
+   }
+
+   /** Creates an integer item */
+   Item( int32 val )
+   {
+      setInteger( (int64) val );
+   }
+
+   /** Creates an integer item */
+   Item( uint32 val )
+   {
+      setInteger( (int64) val );
+   }
+
+
    /** Creates an integer item */
    Item( int64 val )
    {
@@ -210,18 +243,18 @@ public:
    void setRange( int32 val1, int32 val2, bool open )
    {
       type( FLC_ITEM_RANGE );
-      m_data.rstart = val1;
-      m_data.rend = val2;
-      m_data.rstep = 0;
+      m_data.rng.rstart = val1;
+      m_data.rng.rend = val2;
+      m_data.rng.rstep = 0;
       m_base.bits.flags = open? flagOpenRange : 0;
    }
 
    void setRange( int32 val1, int32 val2, int32 step, bool open )
    {
       type( FLC_ITEM_RANGE );
-      m_data.rstart = val1;
-      m_data.rend = val2;
-      m_data.rstep = step;
+      m_data.rng.rstart = val1;
+      m_data.rng.rend = val2;
+      m_data.rng.rstep = step;
       m_base.bits.flags = open? flagOpenRange : 0;
    }
 
@@ -234,7 +267,7 @@ public:
 
    void setString( String *str ) {
       type( FLC_ITEM_STRING );
-      m_data.voidp = str;
+      m_data.ptr.voidp = str;
    }
 
    /** Creates an array item */
@@ -245,7 +278,7 @@ public:
 
    void setArray( CoreArray *array ) {
       type( FLC_ITEM_ARRAY );
-      m_data.voidp = array;
+      m_data.ptr.voidp = array;
    }
 
    /** Creates an object item */
@@ -256,7 +289,7 @@ public:
 
    void setObject( CoreObject *obj ) {
       type( FLC_ITEM_OBJECT );
-      m_data.voidp = obj;
+      m_data.ptr.voidp = obj;
    }
 
    /** Creates an attribute. */
@@ -267,7 +300,7 @@ public:
 
    void setAttribute( Attribute *attrib ) {
       type( FLC_ITEM_ATTRIBUTE );
-      m_data.voidp = attrib;
+      m_data.ptr.voidp = attrib;
    }
 
    /** Creates a dictionary item */
@@ -278,7 +311,7 @@ public:
 
    void setDict( CoreDict *dict ) {
       type( FLC_ITEM_DICT );
-      m_data.voidp = dict;
+      m_data.ptr.voidp = dict;
    }
 
    /** Creates a memory buffer. */
@@ -289,33 +322,79 @@ public:
 
    void setMemBuf( MemBuf *b ) {
       type( FLC_ITEM_MEMBUF );
-      m_data.voidp = b;
+      m_data.ptr.voidp = b;
    }
 
    /** Creates a reference to another item. */
    void setReference( GarbageItem *ref ) {
       type( FLC_ITEM_REFERENCE );
-      m_data.voidp = ref;
+      m_data.ptr.voidp = ref;
    }
-   GarbageItem *asReference() const { return (GarbageItem *) m_data.voidp; }
+   GarbageItem *asReference() const { return (GarbageItem *) m_data.ptr.voidp; }
 
    /** Creates a function item */
-   void setFunction( Symbol *sym, LiveModule *lmod )
+   void setFunction( const Symbol *sym, LiveModule *lmod )
    {
       type( FLC_ITEM_FUNC );
-      m_data.voidp = sym;
-      m_data.m_liveMod = lmod;
+      m_data.ptr.voidp = const_cast<Symbol *>(sym);
+      m_data.ptr.m_liveMod = lmod;
    }
 
+   /** Creates a late binding item.
+      The late binding is just a string in a live module which is
+      resolved into a value by referencing a item in the current
+      context (symbol tables) having the given name at runtime.
+
+      Thus, the string representing the late binding symbol name
+      lives in the live module that generated this LBind. If
+      the module is unloaded, the LBind is invalidated.
+
+      \param lbind The name of the late binding symbol.
+      \param val If provided, a future value (future binding).
+   */
+   void setLBind( String *lbind, GarbageItem *val=0 )
+   {
+      type( FLC_ITEM_LBIND );
+      m_data.ptr.voidp = lbind;
+      m_data.ptr.m_extra = val;
+   }
+
+   /** Returns true if this item is a valid LBind.
+   */
+   bool isLBind() const { return type() == FLC_ITEM_LBIND; }
+   bool isFutureBind() const { return isLBind() && m_data.ptr.m_extra != 0; }
+
+   /** Return the binding name associate with this LBind item.
+   */
+   String *asLBind() const { return (String *) m_data.ptr.voidp; }
+   GarbageItem *asFBind() const { return (GarbageItem *) m_data.ptr.m_extra; }
+
+   const Item &asFutureBind() const;
+   Item &asFutureBind();
+
    /** Creates a method.
       The method is able to remember if it was called with
       a Function pointer or using an external function.
    */
-   Item( CoreObject *obj, Symbol *func, LiveModule *lmod )
+   Item( CoreObject *obj, const Symbol *func, LiveModule *lmod )
    {
       setMethod( obj, func, lmod );
    }
 
+   /** Creates a table/array method.
+      The method is able to remember if it was called with
+      a Function pointer or using an external function.
+   */
+   Item( CoreArray *arr, const Symbol *func, LiveModule *lmod )
+   {
+      setTabMethod( arr, func, lmod );
+   }
+
+   Item( CoreDict *dict, const Symbol *func, LiveModule *lmod )
+   {
+      setTabMethod( dict, func, lmod );
+   }
+
 
    Item( CoreObject *obj, CoreClass *cls )
    {
@@ -326,17 +405,38 @@ public:
       The method is able to remember if it was called with
       a Function pointer or using an external function.
    */
-   void setMethod( CoreObject *obj, Symbol *func, LiveModule *lmod ) {
+   void setMethod( CoreObject *obj, const Symbol *func, LiveModule *lmod ) {
       type( FLC_ITEM_METHOD );
-      m_data.voidp = obj;
-      m_data.m_extra = func;
-      m_data.m_liveMod = lmod;
+      m_data.ptr.voidp = obj;
+      m_data.ptr.m_extra = const_cast<Symbol *>(func);
+      m_data.ptr.m_liveMod = lmod;
    }
 
+   /** Creates a table/array method.
+      The method is able to remember if it was called with
+      a Function pointer or using an external function.
+   */
+   void setTabMethod( CoreArray *arr, const Symbol *func, LiveModule *lmod ) {
+      type( FLC_ITEM_TABMETHOD );
+      m_base.bits.reserved = 0;
+      m_data.ptr.voidp = arr;
+      m_data.ptr.m_extra = const_cast<Symbol *>(func);
+      m_data.ptr.m_liveMod = lmod;
+   }
+
+   void setTabMethod( CoreDict *dict, const Symbol *func, LiveModule *lmod ) {
+      type( FLC_ITEM_TABMETHOD );
+      m_base.bits.reserved = 1;
+      m_data.ptr.voidp = dict;
+      m_data.ptr.m_extra = const_cast<Symbol *>(func);
+      m_data.ptr.m_liveMod = lmod;
+   }
+
+
    void setClassMethod( CoreObject *obj, CoreClass *cls ) {
       type( FLC_ITEM_CLSMETHOD );
-      m_data.voidp = obj;
-      m_data.m_extra = cls;
+      m_data.ptr.voidp = obj;
+      m_data.ptr.m_extra = cls;
    }
 
    /** Creates a class item */
@@ -348,7 +448,7 @@ public:
    void setClass( CoreClass *cls ) {
       type( FLC_ITEM_CLASS );
       // warning: class in extra to be omologue to methodClass()
-      m_data.m_extra = cls;
+      m_data.ptr.m_extra = cls;
    }
 
    /** Sets an item as a FBOM.
@@ -402,16 +502,28 @@ public:
    */
    void setUserPointer( void *tpd )
    {
-      type( FLC_ITEM_POINTER );
-      m_data.voidp = tpd;
+      type( FLC_ITEM_USER_POINTER );
+      m_data.ptr.voidp = tpd;
    }
 
-   void *asUserPointer()
+   void *asUserPointer() const
    {
-      return m_data.voidp;
+      return m_data.ptr.voidp;
    }
 
-   bool isUserPointer() const { return m_base.bits.flags == FLC_ITEM_POINTER; }
+   bool isUserPointer() const { return type() == FLC_ITEM_USER_POINTER; }
+
+   /** Set this item as a user-defined Garbage pointers.
+       VM provides GC-control over them.
+   */
+   void setGCPointer( VMachine *vm, FalconData *ptr, uint32 sig = 0 );
+   void setGCPointer( GarbagePointer *shell, uint32 sig = 0 );
+
+   FalconData *asGCPointer() const;
+   GarbagePointer *asGCPointerShell() const { return m_data.gptr.gcptr; }
+   uint32 asGCPointerSignature()  const { return m_data.gptr.signature; }
+
+   bool isGCPointer() const { return type() == FLC_ITEM_GCPTR; }
 
    /** Tells wether this item is out of band.
       \return true if out of band.
@@ -431,8 +543,16 @@ public:
 
    void copy( const Item &other )
    {
-      m_base = other.m_base;
-      m_data = other.m_data;
+      #if defined( __sparc )
+        //memcpy( this, &other, sizeof(Item) );
+        m_base.whole = other.m_base.whole;
+	m_data.ptr.voidp = other.m_data.ptr.voidp;
+        m_data.ptr.m_extra = other.m_data.ptr.m_extra;
+        m_data.ptr.m_liveMod = other.m_data.ptr.m_liveMod;
+      #else
+        m_base = other.m_base;
+        m_data = other.m_data;
+      #endif
    }
 
    /** Tells if this item is callable.
@@ -455,37 +575,55 @@ public:
 
    numeric asNumeric() const { return m_data.number; }
 
-   int32 asRangeStart() const { return m_data.rstart; }
-   int32 asRangeEnd()  const { return m_data.rend; }
-   int32 asRangeStep()  const { return m_data.rstep; }
+   int32 asRangeStart() const { return m_data.rng.rstart; }
+   int32 asRangeEnd()  const { return m_data.rng.rend; }
+   int32 asRangeStep()  const { return m_data.rng.rstep; }
    bool asRangeIsOpen()  const { return (m_base.bits.flags & flagOpenRange) != 0; }
+   void rangeSetIsOpen( bool b ) { 
+      if( b ) 
+         m_base.bits.flags |= flagOpenRange;
+      else
+         m_base.bits.flags &= ~flagOpenRange;
+   }
 
-   String *asString() const { return (String *) m_data.voidp; }
+   String *asString() const { return (String *) m_data.ptr.voidp; }
    /** Provides a basic string representation of the item.
       Use Falcon::Format for a finer control of item representation.
       \param target a string where the item string representation will be placed.
    */
    void toString( String &target ) const;
-   CoreArray *asArray() const { return (CoreArray *) m_data.voidp; }
-   CoreObject *asObject() const { return (CoreObject *) m_data.voidp; }
-   CoreDict *asDict() const { return ( CoreDict *) m_data.voidp; }
-   MemBuf *asMemBuf() const { return ( MemBuf *) m_data.voidp; }
+   CoreArray *asArray() const { return (CoreArray *) m_data.ptr.voidp; }
+   CoreObject *asObject() const;
+   CoreObject *asObjectSafe() const { return (CoreObject *) m_data.ptr.voidp; }
+   CoreDict *asDict() const { return ( CoreDict *) m_data.ptr.voidp; }
+   MemBuf *asMemBuf() const { return ( MemBuf *) m_data.ptr.voidp; }
 
-   CoreClass *asClass() const { return (CoreClass *) m_data.m_extra; }
-   Symbol *asFunction() const { return (Symbol *) m_data.voidp; }
+   CoreClass *asClass() const { return (CoreClass *) m_data.ptr.m_extra; }
+   const Symbol *asFunction() const { return (const Symbol *) m_data.ptr.voidp; }
 
-   CoreObject *asMethodObject() const { return (CoreObject *) m_data.voidp; }
-   Symbol *asMethodFunction() const { return (Symbol *)m_data.m_extra; }
-   CoreClass *asMethodClass() const { return (CoreClass*) m_data.m_extra; }
-   Attribute *asAttribute() const { return (Attribute *) m_data.voidp; }
+   CoreObject *asMethodObject() const { return (CoreObject *) m_data.ptr.voidp; }
+   CoreArray *asTabMethodArray() const { return (CoreArray *) m_data.ptr.voidp; }
+   CoreDict *asTabMethodDict() const { return (CoreDict *) m_data.ptr.voidp; }
+   bool isTabMethodDict() const { return m_base.bits.reserved==1; }
+   const Symbol *asMethodFunction() const { return (const Symbol *)m_data.ptr.m_extra; }
+   CoreClass *asMethodClass() const { return (CoreClass*) m_data.ptr.m_extra; }
+   Attribute *asAttribute() const { return (Attribute *) m_data.ptr.voidp; }
 
-   LiveModule *asModule() const { return m_data.m_liveMod; }
+   LiveModule *asModule() const { return m_data.ptr.m_liveMod; }
 
    /** Convert current object into an integer.
       This operations is usually done on integers, numeric and strings.
       It will do nothing meaningfull on other types.
    */
    int64 forceInteger() const ;
+   
+   /** Convert current object into an integer.
+      This operations is usually done on integers, numeric and strings.
+      It will do nothing meaningfull on other types.
+      
+      \note this version will throw a code error if the item is not an ordinal.
+   */
+   int64 forceIntegerEx() const ;
 
    /** Convert current object into a numeric.
       This operations is usually done on integers, numeric and strings.
@@ -511,6 +649,7 @@ public:
    bool isReference() const { return type() == FLC_ITEM_REFERENCE; }
    bool isFunction() const { return type() == FLC_ITEM_FUNC; }
    bool isMethod() const { return type() == FLC_ITEM_METHOD; }
+   bool isTabMethod() const { return type() == FLC_ITEM_TABMETHOD; }
    bool isClassMethod() const { return type() == FLC_ITEM_CLSMETHOD; }
    bool isClass() const { return type() == FLC_ITEM_CLASS; }
    bool isFbom() const { return type() == FLC_ITEM_FBOM; }
@@ -661,7 +800,7 @@ public:
       Deep items are the ones that are subject to garbage collecting.
       \return true if the item is deep.
    */
-   bool isDeep() const { return type() < FLC_ITEM_FIRST_DEEP; }
+   bool isDeep() const { return type() >= FLC_ITEM_FIRST_DEEP; }
 };
 
 /** Creates a garbageable version of an item.
