@@ -79,6 +79,8 @@ public:
    virtual bool erase();
    virtual bool insert( const Item &data );
 
+   virtual FalconData *clone() const;
+
    friend class LinearDict;
 };
 
@@ -109,7 +111,7 @@ public:
    ~LinearDict();
 
    virtual uint32 length() const;
-   virtual Item *find( const Item &key );
+   virtual Item *find( const Item &key ) const;
    virtual bool find( const Item &key, DictIterator &iter );
    virtual DictIterator *findIterator( const Item &key );
 
