@@ -1,22 +1,16 @@
 /*
    FALCON - The Falcon Programming Language.
    FILE: linemap.h
-   $Id: linemap.h,v 1.2 2006/11/04 19:21:05 gian Exp $
 
    Line map with module serialization support.
    -------------------------------------------------------------------
    Author: Giancarlo Niccolai
    Begin: dom ago 21 2005
-   Last modified because:
 
    -------------------------------------------------------------------
    (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)
 
    See LICENSE file for licensing details.
-   In order to use this file in its compiled form, this source or
-   part of it you have to read, understand and accept the conditions
-   that are stated in the LICENSE file that comes boundled with this
-   package.
 */
 
 /** \file
