@@ -126,7 +126,7 @@ public:
    /** Destroys all the items.
       Needless to say, this must be called outside any VM.
    */
-   ~MemPool();
+   virtual ~MemPool();
 
    void setOwner( VMachine *owner ) { m_owner = owner; }
 
@@ -139,7 +139,7 @@ public:
    /** Prevents calling the markitem function in case of shallow items. */
    void markItemFast( Item &itm )
    {
-      if( itm.type() >= FLC_ITEM_STRING )
+      if( itm.isDeep() )
          markItem( itm );
    }
 
