@@ -58,6 +58,8 @@ public:
    virtual bool erase();
    virtual bool insert( const Item &item );
 
+   virtual FalconData *clone() const;
+
    friend class PageDict;
 };
 
@@ -65,8 +67,8 @@ class FALCON_DYN_CLASS PageDict: public CoreDict
 {
    VMItemTraits m_itemTraits;
    MapIterator m_traverseIter;
-   uint32 m_version;
    Map m_map;
+   uint32 m_version;
 
 public:
 
@@ -75,7 +77,7 @@ public:
    ~PageDict();
 
    virtual uint32 length() const;
-   virtual Item *find( const Item &key );
+   virtual Item *find( const Item &key ) const;
    virtual bool find( const Item &key, DictIterator &iter );
    virtual DictIterator *findIterator( const Item &key );
    virtual void smartInsert( DictIterator &iter, const Item &key, const Item &value );
