@@ -28,8 +28,35 @@ namespace Falcon {
 
 class VMachine;
 
+/** Structure holding live dependency informations.
+*
+* Modules loaded through "load" directive will export their exported symbols
+* to the VM. Modules referenced through "import" will be linked but won't export
+* symbols, and they will be referenced as "private".
+*/
+
+class ModuleDep: public BaseAlloc
+{
+   Module *m_module;
+   bool m_bIsPrivate;
+public:
+
+   ModuleDep( Module *mod, bool priv = false ):
+      m_module( mod ),
+      m_bIsPrivate( priv )
+   {
+      mod->incref();
+   }
+
+   ~ModuleDep() { m_module->decref(); }
+
+   Module *module() const { return m_module; }
+   bool isPrivate() const { return m_bIsPrivate; }
+   void setPrivate( bool mode ) { m_bIsPrivate = mode; }
+};
+
 /** Map of module names-> modules.
-    ( const String *, Module * )
+    ( const String *, ModuleDep * )
 */
 class FALCON_DYN_CLASS ModuleMap: public Map
 {
@@ -37,11 +64,17 @@ public:
    ModuleMap();
 };
 
+/** Vector of ModuleDep objects.
+*
+* Ownership is in not in the vector, the owner class must destroy ModuleDep items at
+* when required.
+*/
 class FALCON_DYN_CLASS ModuleVector: public GenericVector
 {
 public:
    ModuleVector();
-   Module *moduleAt( uint32 pos ) const { return *(Module**) at(pos); }
+   Module *moduleAt( uint32 pos ) const { return (*(ModuleDep**) at(pos))->module(); }
+   ModuleDep *moduleDepAt( uint32 pos ) const { return *(ModuleDep**) at(pos); }
 };
 
 /** Runtime code representation.
@@ -74,10 +107,11 @@ disk, so that it may become a somewhat complete linker.
 class FALCON_DYN_CLASS Runtime: public BaseAlloc
 {
    ModuleMap m_modules;
-   Map m_modPending;
    ModuleVector m_modvect;
    ModuleLoader *m_loader;
    VMachine *m_provider;
+   Map m_modPending;
+   bool m_hasMainModule;
 
 public:
 
@@ -142,27 +176,18 @@ public:
       This function adds a module to the runtime library and then it
       links it in two steps.
 
-      First, link() method is called to fill the module global variables table,
-      (which may be empty), by importing external symbols from the already
-      added modules. Then all exported symbol is uploaded in the global symbols
-      table (m_gsyms).
-
-      Module symbol exporting overrides previous export requests. In example, if
-      the rtl module (providing and exporting \b printl function ) and then another
-      module exporting a symbol printl is added, all the subsequent references to
-      printl will refer to the latter definition. However, modules importing printl()
-      before the latter override will still refer to the original printl(). To override
-      \b all instance of an already defined function, just assign it to something else
-      everywhere in the executed module(s).
-
       When a module is added to the runtime, its reference count is incremented, and
       a record containing its ID (relative position) is added. The ID will soft-link
       the module with its own global variable representation in the executing VM (i.e. Module N
       will have global variable vector number N, module K will refer to variables in the K vector
       and so on).
 
+      \param mod The module to be added.
+      \param bIsPrivate false (default) when linking requires exported symbols to be published
+                        globally in the VM.
+      \return true if the module have been added, false on module resolution error.
    */
-   bool addModule( Module *mod );
+   bool addModule( Module *mod, bool bIsPrivate = false );
 
    /** Return the symbol tably containing the global symbols.
       As a symbol table is just a symbol map that self-deletes owned symbol,
@@ -185,9 +210,9 @@ public:
    */
    Module *findModule( const String &name )
    {
-      Module **modp = (Module **) m_modules.find( &name );
+      ModuleDep **modp = (ModuleDep **) m_modules.find( &name );
       if ( modp != 0 )
-         return *modp;
+         return (*modp)->module();
       return 0;
    }
 
@@ -206,9 +231,11 @@ public:
       and if load is succesfull, then the module is added to the runtime.
       \param name the logical name of the module to be loaded
       \param parent the logical name of the parent module, if any
+      \param bIsPrivate false (default) to allow the module to export its
+            symbols to the VM, true otherwise.
       \return true on success, false on load or dependency resolution errors.
    */
-   bool loadName( const String &name, const String &parent = "" );
+   bool loadName( const String &name, const String &parent = "", bool bIsPrivate=false );
 
    /** Loads the given module and adds it to the runtime.
       This is actually a just shortcut to load a module
@@ -216,15 +243,35 @@ public:
       and if load is succesfull, then the module is added to the runtime.
 
       \param file the file name of the module to be loaded
+      \param bIsPrivate false (default) to allow the module to export its
+            symbols to the VM, true otherwise.
       \return true on success, false on load or dependency resolution errors.
    */
-   bool loadFile( const String &file );
+   bool loadFile( const String &file, bool bIsPrivate=false );
 
    /** Returns true if there are still some pending modules.
       This means that the module list may not be completed in case the runtime
       is not using a loader to resolve dependencies.
    */
    bool hasPendingModules() const { return ! m_modPending.empty(); }
+
+   /** Returns true if this loader top module is the main module for a final application.
+      By default, this is true unless changed with hasMainModule(bool).
+   */
+   bool hasMainModule() const { return m_hasMainModule; }
+
+   /** Changes the relevance of this runtime.
+      If the runtime "has the main module", then the topmost module will be added as
+      main when the runtime is linked to the target vm.
+
+      This is the default behavior.
+
+      As some runtime may be used to link sub-components which are not meant to
+      build a complete application, this method is provided to inhibit this behavior.
+      \param b true if this runtime will provide the main module to the
+               VM at link time, false otherwise.
+   */
+   void hasMainModule( bool b ) { m_hasMainModule = b; }
 };
 
 
