@@ -45,9 +45,14 @@ private:
    bool m_addEol;
    bool m_lineFilled;
    bool m_bIsDirectiveLine;
+   bool m_incremental;
+   bool m_lineContContext;
    uint32 m_chrEndString;
 
    Stream *m_in;
+   List m_streams;
+   List m_streamLines;
+
    Compiler *m_compiler;
    String m_string;
 
@@ -73,7 +78,7 @@ private:
       e_floatNumber_e1,
       e_operator,
       e_symbol,
-      e_litString,
+      e_litString
    } t_state;
 
    t_state m_state;
@@ -87,6 +92,9 @@ private:
 
    t_mode m_mode;
    bool m_bParsingFtd;
+   bool m_bWasntEmpty;
+   String m_whiteLead;
+
 
    /** Scans m_string for recognized tokens, and eventually returns them. */
    int checkUnlimitedTokens( uint32 nextChar );
@@ -132,7 +140,8 @@ private:
    int lex_eval();
 
 public:
-   SrcLexer( Compiler *comp, Stream *in );
+   SrcLexer( Compiler *comp );
+   ~SrcLexer();
 
    /** Return current line in file (starting from 1). */
    int line() const {
@@ -170,11 +179,22 @@ public:
    void *value() const { return m_value; }
    int lex();
 
+   void input( Stream *i );
    Stream *input() const { return m_in; }
 
+   /** Resets the lexer, preparing it for another compilation. */
+   void reset();
+
    bool parsingFtd() const { return m_bParsingFtd; }
    void parsingFtd( bool b );
 
+   bool hasOpenContexts() { return m_contexts != 0 || m_squareContexts != 0 || m_lineContContext != 0; }
+   bool incremental() const { return m_incremental; }
+   void incremental( bool b ) { m_incremental = b; }
+
+   void appendStream( Stream *s );
+   void parseMacro();
+   void parseMacroCall();
 
 };
 
