@@ -35,7 +35,7 @@ typedef struct tag_StackFrame
 {
    Item header;
 
-   Symbol *m_symbol;
+   const Symbol *m_symbol;
    uint32 m_ret_pc;
    uint32 m_call_pc;
    const Module *m_module;
@@ -47,6 +47,7 @@ typedef struct tag_StackFrame
    uint32 m_stack_base;
    uint32 m_try_base;
    Item m_sender;
+   Item m_binding;
 
    ext_func_frame_t m_endFrameFunc;
 } StackFrame;
