@@ -69,7 +69,6 @@ class FALCON_DYN_CLASS RangeDecl: public BaseAlloc
    Value *m_rend;
    Value *m_step;
 
-
 public:
    RangeDecl( Value *start, Value *end = 0, Value *step = 0 ):
       m_rstart( start ),
@@ -104,7 +103,7 @@ public:
       t_symdef,
       t_self,
       t_sender,
-      t_funcvar,  //!< Inner functional variable.
+      t_lbind,
 
       t_byref,
       t_array_decl,
@@ -234,13 +233,6 @@ public:
    */
    VarDef *genVarDef();
 
-   /** Creates a Falcon::VarDef using the contents of this object.
-      This version will create a VarDef also for symbols and references.
-      \return a newly allocated prodef that has the same contents a the value, or 0
-         for complex values.
-   */
-   VarDef *genVarDefSym();
-
    bool isImmediate() const {
       return m_type == t_nil ||
              m_type == t_imm_bool ||
@@ -251,7 +243,7 @@ public:
 
    bool isSimple() const {
       return isImmediate() ||
-             m_type == t_symbol || m_type == t_symdef ||
+             m_type == t_symbol || m_type == t_symdef || m_type == t_lbind ||
              m_type == t_self || m_type == t_sender;
    }
 
@@ -260,8 +252,8 @@ public:
          case t_imm_integer: return asInteger() != 0;
          case t_imm_num:  return asNumeric() != 0.0;
          case t_imm_string: return asString()->size() != 0;
+         default: return false;
       }
-      return false;
    }
 
    bool asBool() const { return m_content.asBool; }
@@ -269,6 +261,7 @@ public:
    numeric asNumeric() const { return m_content.asNumeric; }
    String *asString() const { return m_content.asString; }
    String *asSymdef() const { return m_content.asString; }
+   String *asLBind() const { return m_content.asString; }
    Symbol *asSymbol() const { return m_content.asSymbol; }
 
    Value *asReference() const { return m_content.asRef; }
@@ -291,7 +284,7 @@ public:
    void setRange( RangeDecl *val ) { m_type = t_range_decl; m_content.asRange = val; }
    void setSelf() { m_type = t_self; }
    void setSender() { m_type = t_sender; }
-
+   void setLBind( String *val ) { m_type = t_lbind; m_content.asString = val; }
 
    bool isNil() const { return m_type == t_nil; }
    bool isBool() const { return m_type == t_imm_bool; }
@@ -307,6 +300,7 @@ public:
    bool isSelf() const { return m_type == t_self; }
    bool isSender() const { return m_type == t_sender; }
    bool isRange() const { return m_type == t_range_decl; }
+   bool isLBind() const { return m_type == t_lbind; }
 
    Value &operator =( const Value &other ) {
       copy( other );
@@ -353,7 +347,7 @@ public:
 };
 
 namespace traits {
-   extern ValuePtrTraits t_valueptr;
+   extern ValuePtrTraits &t_valueptr();
 }
 
 
@@ -411,6 +405,7 @@ public:
       t_indirect,
 
       t_assign,
+      t_fbind,
 
       t_aadd,
       t_asub,
@@ -424,8 +419,14 @@ public:
       t_ashl,
       t_ashr,
 
+      t_eval,
+      t_deoob,
+      t_oob,
+      t_xoroob,
+      t_isoob,
+
       /** An optimized expression is like an unary operator */
-      t_optimized,
+      t_optimized
    } operator_t;
 
 private:
@@ -436,10 +437,10 @@ private:
 
 public:
    Expression( operator_t t, Value *first, Value *second = 0, Value *third = 0 ):
+      m_operator( t ),
       m_first( first ),
       m_second( second ),
-      m_third( third ),
-      m_operator( t )
+      m_third( third )
    {}
 
    Expression( const Expression &other );
@@ -487,8 +488,11 @@ public:
          case t_notin:
          case t_provides:
             return true;
+
+         default:
+            return false;
       }
-      return false;
+      // returning from switch
    }
 };
 
@@ -524,7 +528,6 @@ public:
       t_global,
       t_pass,
 
-      t_object,
       t_class,
       t_function,
       t_propdef,
@@ -1155,13 +1158,17 @@ class FALCON_DYN_CLASS StmtClass: public StmtCallable
    /** if this class is a clone it must delete it's constructor statement. */
    bool m_bDeleteCtor;
 
+   Symbol *m_singleton;
+   /** set of expressions (values, usually inherit calls) to be prepended to the constructor */
+   ArrayDecl m_initExpressions;
 public:
 
    StmtClass( uint32 line, Symbol *name ):
       StmtCallable( line, t_class, name ),
+      m_ctor(0),
       m_initGiven( false ),
       m_bDeleteCtor( false ),
-      m_ctor(0)
+      m_singleton(0)
    {}
 
    StmtClass( const StmtClass &other );
@@ -1181,6 +1188,13 @@ public:
    bool initGiven() const { return m_initGiven; }
    void initGiven( bool val ) { m_initGiven = val; }
 
+   void addInitExpression( Value *expr ) { m_initExpressions.pushBack( expr ); }
+   const ArrayDecl& initExpressions() const { return m_initExpressions; }
+   ArrayDecl& initExpressions() { return m_initExpressions; }
+
+   /** Singleton associated to this class, if any. */
+   Symbol *singleton() const { return m_singleton; }
+   void singleton( Symbol *s ) { m_singleton = s; }
    virtual Statement *clone() const;
 };
 
@@ -1188,11 +1202,11 @@ class FALCON_DYN_CLASS StmtFunction: public StmtCallable
 {
 
 private:
+   int m_lambda_id;
    StatementList m_staticBlock;
    StatementList m_statements;
-
-   int m_lambda_id;
    const StmtClass *m_ctor_for;
+
 public:
 
    StmtFunction( uint32 line, Symbol *name ):
