@@ -22,10 +22,10 @@
 
 namespace Falcon {
 
-
 class FALCON_DYN_CLASS ElementTraits
 {
 public:
+   virtual ~ElementTraits();
 	virtual uint32 memSize() const = 0;
 	virtual void init( void *itemZone ) const = 0;
 	virtual void copy( void *targetZone, const void *sourceZone ) const = 0;
@@ -70,6 +70,7 @@ public:
 class FALCON_DYN_CLASS StringPtrOwnTraits: public StringPtrTraits
 {
 public:
+   virtual ~StringPtrOwnTraits() {}
    virtual bool owning() const;
 	virtual void destroy( void *item ) const;
 };
@@ -87,11 +88,11 @@ public:
 
 
 namespace traits {
-	extern FALCON_DYN_SYM StringTraits t_string;
-	extern FALCON_DYN_SYM VoidpTraits t_voidp;
-	extern FALCON_DYN_SYM IntTraits t_int;
-	extern FALCON_DYN_SYM StringPtrTraits t_stringptr;
-	extern FALCON_DYN_SYM StringPtrOwnTraits t_stringptr_own;
+	extern FALCON_DYN_SYM StringTraits &t_string();
+	extern FALCON_DYN_SYM VoidpTraits &t_voidp();
+	extern FALCON_DYN_SYM IntTraits &t_int();
+	extern FALCON_DYN_SYM StringPtrTraits &t_stringptr();
+	extern FALCON_DYN_SYM StringPtrOwnTraits &t_stringptr_own();
 }
 
 }
