@@ -25,6 +25,7 @@
 #include <falcon/genericlist.h>
 #include <fasm/pseudo.h>
 #include <falcon/basealloc.h>
+#include <falcon/stringstream.h>
 
 #include <stdlib.h>
 
@@ -48,7 +49,6 @@ class  Module;
 class FALCON_DYN_CLASS AsmCompiler: public BaseAlloc
 {
    AsmLexer *m_lexer;
-   Stream *m_out;
    int m_errors;
 
    /** Map of label definitions.
@@ -72,6 +72,9 @@ class FALCON_DYN_CLASS AsmCompiler: public BaseAlloc
    ErrorHandler *m_errhand;
 
    Module *m_module;
+   StringStream *m_outTemp;
+   uint32 m_currentLine;
+   uint32 m_pc;
 
    void clearSwitch();
 public:
@@ -95,9 +98,8 @@ public:
 
       \param mod the module object.
       \param in the stream where the assembly is found.
-      \param out the stream where the code will be placed.
    */
-   AsmCompiler( Module *mod, Stream *in, Stream *out );
+   AsmCompiler( Module *mod, Stream *in );
 
    virtual ~AsmCompiler();
 
@@ -129,7 +131,11 @@ public:
    LabelDef *addLabel( const String &name );
    void defineLabel( LabelDef *def );
    void addExtern( Pseudo *val, Pseudo *line );
-   void addLoad( Pseudo *val );
+   void addLoad( Pseudo *val, bool isFile = false );
+   /** Import in a namespace */
+   void addImport( Pseudo *val, Pseudo *line, Pseudo *mod=0, Pseudo *nspace=0, bool isFile = false );
+   /** Import with local alias (import as) */
+   void addAlias( Pseudo *val, Pseudo *line, Pseudo *mod, Pseudo *alias, bool isFile = false );
    void addDLine( Pseudo *line );
 
    void addInstr( unsigned char opCode, Pseudo *op1=0, Pseudo *op2=0, Pseudo *op3=0 );
@@ -143,7 +149,6 @@ public:
    void classHas( Pseudo *has );
    void classHasnt( Pseudo *hasnt );
    void addInherit( Pseudo *baseclass );
-   void addInheritParam( Pseudo *param );
 
    void raiseError( int errorNum, int errorLine=0);
    void raiseError( int errorNum, const String &errorp, int errorLine=0);
@@ -156,6 +161,7 @@ public:
    bool isParam( Pseudo *op1 ) const;
    bool isLocal( Pseudo *op1 ) const ;
    bool isExtern( Pseudo *op1 ) const ;
+   void closeMain();
 
    Pseudo *regA_Inst();
    Pseudo *regB_Inst();
