@@ -57,6 +57,7 @@ public:
       imm_string,
       imm_range,
       tdispstring,
+      tlbind,
       tname,
       tsymbol,
       tswitch_list,
@@ -85,12 +86,11 @@ private:
       } range;
    } pseudo_value;
 
-   type_t m_type;
    int m_line;
-
-   pseudo_value m_value;
+   type_t m_type;
    bool m_disp;
    bool m_fixed;
+   pseudo_value m_value;
 
 public:
 
@@ -234,7 +234,7 @@ public:
 };
 
 namespace traits {
-   extern PseudoPtrTraits t_pseudoptr;
+   extern PseudoPtrTraits &t_pseudoptr();
 }
 
 }
