@@ -109,10 +109,10 @@ FALCON_FUNC Compiler_init( ::Falcon::VMachine *vm )
          return;
       }
 
-      iface = new CompilerIface( vm->self().asObject(), *i_path->asString() );
+      iface = new CompilerIface( *i_path->asString() );
    }
    else
-      iface = new CompilerIface( vm->self().asObject() );
+      iface = new CompilerIface();
 
    // set our VM as the error handler for this loader.
    iface->loader().errorHandler( vm );
@@ -151,7 +151,7 @@ void internal_link( ::Falcon::VMachine *vm, Module *mod, CompilerIface *iface )
    Runtime rt( &iface->loader(), vm );
 
    // let's try to link
-   if ( ! rt.addModule( mod ) || ! vm->link( &rt ) )
+   if ( ! rt.addModule( mod, true ) || ! vm->link( &rt ) )
    {
       // VM should have raised the errors.
       mod->decref();
@@ -274,7 +274,7 @@ FALCON_FUNC Compiler_loadByName( ::Falcon::VMachine *vm )
    CoreObject *self = vm->self().asObject();
    CompilerIface *iface = static_cast<CompilerIface *>( self->getUserData() );
 
-   Symbol *caller_sym;
+   const Symbol *caller_sym;
    const Module *caller_mod;
    String modname;
    if ( vm->getCaller( caller_sym, caller_mod ) )
