@@ -134,7 +134,7 @@ public:
 };
 
 
-class ConfigFile: public UserData
+class ConfigFile: public FalconData
 {
    String m_fileName;
 
@@ -165,6 +165,8 @@ class ConfigFile: public UserData
    ListElement *m_currentValue;
 
    uint32 m_errorLine;
+   bool m_bUseUnixComments;
+   bool m_bUseUnixSpecs;
 
    bool getFirstKey_internal( ConfigSection *sect, const String &prefix, String &key );
    void setValue_internal( ConfigSection *sect, const String &key, const String &value );
@@ -172,8 +174,6 @@ class ConfigFile: public UserData
    bool removeValue_internal( ConfigSection *sect, const String &key );
    bool removeCategory_internal( ConfigSection *sect, const String &key );
 
-   bool m_bUseUnixComments;
-   bool m_bUseUnixSpecs;
 public:
    ConfigFile( const String &fileName, const String &encoding );
    virtual ~ConfigFile();
@@ -224,6 +224,9 @@ public:
 
    bool removeSection( const String &key );
    void clearMainSection();
+
+   virtual void gcMark( VMachine *mp ) {}
+   virtual FalconData *clone() const { return 0; }
 };
 
 }
