@@ -34,17 +34,17 @@
    and written synchronously and polled for activity.
 
    To provide this functionality, the Process class requires the service called
-   “Stream” normally provided by the RTL library. Embedders that wish to allow the
-   scripts to load this module should provide RTL to scripts, or provide otherwise
+   “Stream” normally provided by the core module. Embedders that wish to allow the
+   scripts to load this module should provide core to scripts, or provide otherwise
    the “Stream” service in the Virtual Machines that will run those scripts.
    Failing to do so will cause the stream oriented methods of the Process class to
    raise an error. The generic process management functions in the module, and also
    the generic child-process management methods in the Process class do not require
-   this service, so embedders not willing to provide RTL may just turn overload the
+   this service, so embedders not willing to provide core may just turn overload the
    sensible Process methods or mask the Process class right away (or just ignore
    this fact letting the error to be raised in case of mis-usage).
 
-   As the Falcon command line automatically loads the RTL, this remark does not
+   As the Falcon command line automatically loads the core module, this remark does not
    apply to stand-alone scripts.
 
    The Process module declares a ProcessError class, derived from core Error class,
@@ -87,16 +87,24 @@ FALCON_MODULE_DECL( const Falcon::EngineData &data )
    //============================================================
    // Minimal system api
    //
-   self->addExtFunc( "system", Falcon::Ext::falcon_system );
-   self->addExtFunc( "systemCall", Falcon::Ext::falcon_systemCall );
-   self->addExtFunc( "exec", Falcon::Ext::falcon_exec );
+   self->addExtFunc( "system", Falcon::Ext::falcon_system )->
+      addParam("command")->addParam("background");
+   self->addExtFunc( "systemCall", Falcon::Ext::falcon_systemCall )->
+      addParam("command")->addParam("background");
+   self->addExtFunc( "pread", Falcon::Ext::falcon_pread )->
+      addParam("command")->addParam("background");
+   self->addExtFunc( "exec", Falcon::Ext::falcon_exec )->
+      addParam("command");
    self->addExtFunc( "processId", Falcon::Ext::falcon_processId );
-   self->addExtFunc( "processKill", Falcon::Ext::falcon_processKill );
+   self->addExtFunc( "processKill", Falcon::Ext::falcon_processKill )->
+      addParam("pid")->addParam("severe");
 
    //============================================================
    // Process Enumerator class
    //
    Falcon::Symbol *pe_class = self->addClass( "ProcessEnum", Falcon::Ext::ProcessEnum_init );
+   pe_class->getClassDef()->setObjectManager( &Falcon::core_falcon_data_manager );
+
    self->addClassProperty( pe_class, "name" );
    self->addClassProperty( pe_class, "pid" );
    self->addClassProperty( pe_class, "parentPid" );
@@ -108,9 +116,12 @@ FALCON_MODULE_DECL( const Falcon::EngineData &data )
    //============================================================
    // Process class
    Falcon::Symbol *proc_class = self->addClass( "Process", Falcon::Ext::Process_init );
+   proc_class->getClassDef()->setObjectManager( &Falcon::core_falcon_data_manager );
    self->addClassMethod( proc_class, "wait", Falcon::Ext::Process_wait );
-   self->addClassMethod( proc_class, "terminate", Falcon::Ext::Process_terminate );
-   self->addClassMethod( proc_class, "value", Falcon::Ext::Process_value );
+   self->addClassMethod( proc_class, "terminate", Falcon::Ext::Process_terminate ).asSymbol()->
+      addParam("severe");
+   self->addClassMethod( proc_class, "value", Falcon::Ext::Process_value ).asSymbol()->
+      addParam("wait");
    self->addClassMethod( proc_class, "getInput", Falcon::Ext::Process_getInput );
    self->addClassMethod( proc_class, "getOutput", Falcon::Ext::Process_getOutput );
    self->addClassMethod( proc_class, "getAux", Falcon::Ext::Process_getAux );
@@ -136,3 +147,4 @@ FALCON_MODULE_DECL( const Falcon::EngineData &data )
 
 
 /* end of process.cpp */
+
