@@ -102,30 +102,36 @@ FALCON_MODULE_DECL(const Falcon::EngineData &data )
                  This usually means that the accepting thread has become unavailable.
    */
    Falcon::Symbol *c_errcode = self->addClass( "NetErrorCode" );
-   self->addClassProperty( c_errcode, "generic")->setInteger( FALSOCK_ERR_GENERIC );
-   self->addClassProperty( c_errcode, "resolv")->setInteger( FALSOCK_ERR_RESOLV );
-   self->addClassProperty( c_errcode, "create")->setInteger( FALSOCK_ERR_CREATE );
-   self->addClassProperty( c_errcode, "send")->setInteger( FALSOCK_ERR_SEND );
-   self->addClassProperty( c_errcode, "receive")->setInteger( FALSOCK_ERR_RECV );
-   self->addClassProperty( c_errcode, "close")->setInteger( FALSOCK_ERR_CLOSE );
-   self->addClassProperty( c_errcode, "bind")->setInteger( FALSOCK_ERR_BIND );
-   self->addClassProperty( c_errcode, "accept")->setInteger( FALSOCK_ERR_ACCEPT );
+   self->addClassProperty( c_errcode, "generic").setInteger( FALSOCK_ERR_GENERIC );
+   self->addClassProperty( c_errcode, "resolv").setInteger( FALSOCK_ERR_RESOLV );
+   self->addClassProperty( c_errcode, "create").setInteger( FALSOCK_ERR_CREATE );
+   self->addClassProperty( c_errcode, "send").setInteger( FALSOCK_ERR_SEND );
+   self->addClassProperty( c_errcode, "receive").setInteger( FALSOCK_ERR_RECV );
+   self->addClassProperty( c_errcode, "close").setInteger( FALSOCK_ERR_CLOSE );
+   self->addClassProperty( c_errcode, "bind").setInteger( FALSOCK_ERR_BIND );
+   self->addClassProperty( c_errcode, "accept").setInteger( FALSOCK_ERR_ACCEPT );
 
 
    //====================================
    // Generic functions
 
    self->addExtFunc( "getHostName", Falcon::Ext::falcon_getHostName );
-   self->addExtFunc( "resolveAddress", Falcon::Ext::resolveAddress );
-   self->addExtFunc( "socketErrorDesc", Falcon::Ext::socketErrorDesc );
+   self->addExtFunc( "resolveAddress", Falcon::Ext::resolveAddress )->
+      addParam("address");
+   self->addExtFunc( "socketErrorDesc", Falcon::Ext::socketErrorDesc )->
+      addParam("code");
 
    // private class socket.
    Falcon::Symbol *c_socket = self->addClass( "Socket", Falcon::Ext::Socket_init, false );
+   c_socket->getClassDef()->setObjectManager( &Falcon::core_falcon_data_manager );
    self->addClassMethod( c_socket, "getTimeout", Falcon::Ext::Socket_getTimeout );
-   self->addClassMethod( c_socket, "setTimeout", Falcon::Ext::Socket_setTimeout );
+   self->addClassMethod( c_socket, "setTimeout", Falcon::Ext::Socket_setTimeout ).asSymbol()->
+      addParam("timeout");
    self->addClassMethod( c_socket, "dispose", Falcon::Ext::Socket_dispose );
-   self->addClassMethod( c_socket, "readAvailable", Falcon::Ext::Socket_readAvailable );
-   self->addClassMethod( c_socket, "writeAvailable", Falcon::Ext::Socket_writeAvailable );
+   self->addClassMethod( c_socket, "readAvailable", Falcon::Ext::Socket_readAvailable ).asSymbol()->
+      addParam("timeout");
+   self->addClassMethod( c_socket, "writeAvailable", Falcon::Ext::Socket_writeAvailable ).asSymbol()->
+      addParam("timeout");
    self->addClassMethod( c_socket, "getService", Falcon::Ext::Socket_getService );
    self->addClassMethod( c_socket, "getHost", Falcon::Ext::Socket_getHost );
    self->addClassMethod( c_socket, "getPort", Falcon::Ext::Socket_getPort );
@@ -135,10 +141,13 @@ FALCON_MODULE_DECL(const Falcon::EngineData &data )
    Falcon::Symbol *tcpsocket = self->addClass( "TCPSocket", Falcon::Ext::TCPSocket_init );
    tcpsocket->setWKS( true ); // needed by TCPServer
    tcpsocket->getClassDef()->addInheritance(  new Falcon::InheritDef( c_socket ) );
-   self->addClassMethod( tcpsocket, "connect", Falcon::Ext::TCPSocket_connect );
+   self->addClassMethod( tcpsocket, "connect", Falcon::Ext::TCPSocket_connect ).asSymbol()->
+      addParam("host")->addParam("service");
    self->addClassMethod( tcpsocket, "isConnected", Falcon::Ext::TCPSocket_isConnected );
-   self->addClassMethod( tcpsocket, "send", Falcon::Ext::TCPSocket_send );
-   self->addClassMethod( tcpsocket, "recv", Falcon::Ext::TCPSocket_recv );
+   self->addClassMethod( tcpsocket, "send", Falcon::Ext::TCPSocket_send ).asSymbol()->
+      addParam("buffer")->addParam("size")->addParam("start");
+   self->addClassMethod( tcpsocket, "recv", Falcon::Ext::TCPSocket_recv ).asSymbol()->
+      addParam("bufOrSize");
    self->addClassMethod( tcpsocket, "close", Falcon::Ext::TCPSocket_close );
    self->addClassMethod( tcpsocket, "closeRead", Falcon::Ext::TCPSocket_closeRead );
    self->addClassMethod( tcpsocket, "closeWrite", Falcon::Ext::TCPSocket_closeWrite );
@@ -146,15 +155,20 @@ FALCON_MODULE_DECL(const Falcon::EngineData &data )
    Falcon::Symbol *udpsocket = self->addClass( "UDPSocket", Falcon::Ext::UDPSocket_init );
    udpsocket->getClassDef()->addInheritance(  new Falcon::InheritDef( c_socket ) );
    self->addClassMethod( udpsocket, "broadcast", Falcon::Ext::UDPSocket_broadcast );
-   self->addClassMethod( udpsocket, "sendTo", Falcon::Ext::UDPSocket_sendTo );
-   self->addClassMethod( udpsocket, "recv", Falcon::Ext::UDPSocket_recv );
+   self->addClassMethod( udpsocket, "sendTo", Falcon::Ext::UDPSocket_sendTo ).asSymbol()->
+      addParam("host")->addParam("service")->addParam("buffer")->addParam("size")->addParam("start");
+   self->addClassMethod( udpsocket, "recv", Falcon::Ext::UDPSocket_recv ).asSymbol()->
+      addParam("bufOrSize");
    self->addClassProperty( udpsocket, "remote" );
    self->addClassProperty( udpsocket, "remoteService" );
 
    Falcon::Symbol *tcpserver = self->addClass( "TCPServer", Falcon::Ext::TCPServer_init );
+   tcpserver->getClassDef()->setObjectManager( &Falcon::core_falcon_data_manager );
    self->addClassMethod( tcpserver, "dispose", Falcon::Ext::TCPServer_dispose );
-   self->addClassMethod( tcpserver, "bind", Falcon::Ext::TCPServer_bind );
-   self->addClassMethod( tcpserver, "accept", Falcon::Ext::TCPServer_accept );
+   self->addClassMethod( tcpserver, "bind", Falcon::Ext::TCPServer_bind ).asSymbol()->
+      addParam("addrOrService")->addParam("service");
+   self->addClassMethod( tcpserver, "accept", Falcon::Ext::TCPServer_accept ).asSymbol()->
+      addParam("timeout");
    self->addClassProperty( tcpserver, "lastError" );
 
    //==================================================
@@ -170,3 +184,4 @@ FALCON_MODULE_DECL(const Falcon::EngineData &data )
 }
 
 /* end of socket.cpp */
+
